/*
	   Merges all the Alcott data together
*/


* --------------------------------------------------------------------------------------
* load the different blocks 
* --------------------------------------------------------------------------------------

foreach VAL in 9900 0108 0809 0910 1112 1213 1314 1415 1516 { 
	
	do "$code_asi/Import_ASI_`VAL'.do"
}

do "$code_asi/Import_ASI_merge_09_15.do"

* --------------------------------------------------------------------------------------
* 1999-2015
* --------------------------------------------------------------------------------------
{
	* Fix 1999 and 2000, industry code is string and has weird characters
	use "$output/asi9899.dta", clear
	cap replace ind_code5dig = "" if strpos(ind_code5dig, "X") | strpos(ind_code5dig, "Y") ///
		| strpos(ind_code5dig, "Z")
	destring ind_code5dig, replace
	replace year = 1999
	append using "$output/asi9900.dta", force
	cap replace ind_code5dig = "" if strpos(ind_code5dig, "X") | strpos(ind_code5dig, "Y") ///
		| strpos(ind_code5dig, "Z")
	destring ind_code5dig, replace
	replace year = 2000 if year == 9900

	* Stack remaining data
	foreach yr in 0001 0102 0203 0304 0405 0506 0607 0708 0809 0910 1011 1112 1213 1314 1415 {
		disp "Year: `yr'"
		append using "$output/asi`yr'.dta", force
	}

	* Recreate "total" capital variables for 2002-2008, very off from aggregates
	local type "net grss"
	local time "open close"

	mvencode grss_vl_close_asset_*, mv(0) o
	mvencode grss_vl_open_asset_*, mv(0) o
	// drop grss_vl_open_asset_* grss_vl_close_asset_*
	mvencode dep_upto_yr_s_asset_*, mv(0) o
	mvencode dep_upto_yr_e_asset_*, mv(0) o
	mvencode net_vl_open_asset_*, mv(0) o
	mvencode net_vl_close_asset_*, mv(0) o

	local assets "land pl_mach comp oth building trans polu" // Exclude capital work in progress
	foreach asset in `assets' {
		disp "`asset'"
	}

	foreach val in `assets' {
		replace grss_vl_open_asset_`val' = dep_upto_yr_s_asset_`val' + net_vl_open_asset_`val' if year >= 2002 & year <= 2008
		replace grss_vl_close_asset_`val' = dep_upto_yr_e_asset_`val' + net_vl_close_asset_`val' if year >= 2002 & year <= 2008
	}

	foreach x in `type' {
		foreach y in `time' {
			replace `x'_vl_`y'_asset_total = `x'_vl_`y'_asset_building + ///
				`x'_vl_`y'_asset_comp + ///
				`x'_vl_`y'_asset_oth + `x'_vl_`y'_asset_pl_mach + ///
				`x'_vl_`y'_asset_polu + `x'_vl_`y'_asset_trans + ///
				`x'_vl_`y'_asset_land if year >= 2002 & year <= 2008
		}
	}

	* Create "materials" variable that accounts for all raw materials, imported or not
	mvencode item_purchase_*, mv(0) o
	egen materials = rowtotal(item_purchase_id_inp_* item_purchase_co_inp_*)
	replace materials = materials - item_purchase_id_inp_total - ///
		item_purchase_id_inp_tot_bas - item_purchase_id_inp_tot_nbas - item_purchase_co_inp_total


	* AK: dropping permid to avid error: figure out later 
	drop permid
	
	 
	* Start renaming
	#delimit ;
	rename ind_code4dig		 	nic_4d;
	rename ind_code5dig			nic_5d;
	rename item_grss_sale_prod_total	grsale;
	rename grss_vl_open_asset_total		grossopening_total;
	rename grss_vl_close_asset_total	grossclosing_total;
	rename district_code 			distcode;
	rename year_initial			inityr;
	rename rural				ruralurbancode;
	rename net_vl_open_asset_total		fcapopen_total;
	rename net_vl_close_asset_total		fcapclose_total;
	rename multiplier			mult;
	rename type_owner			owncode;
	rename type_organ			opclcode;
	rename factory_id			permid;
	rename closing_cap_li_sub_inv		rmstcl;
	rename opening_cap_li_sub_inv		rmstop;
	rename opening_cap_li_tot_inv		invopen;
	rename closing_cap_li_tot_inv		invclose;
	rename net_vl_open_asset_land 		fcapopen_land;
	rename net_vl_close_asset_land		fcapclose_land;
	rename net_vl_open_asset_building	fcapopen_building;
	rename net_vl_close_asset_building	fcapclose_building;
	rename net_vl_open_asset_comp		fcapopen_comp;
	rename net_vl_close_asset_comp		fcapclose_comp;
	rename net_vl_open_asset_pl_mach 	fcapopen_pl_mach;
	rename net_vl_close_asset_pl_mach	fcapclose_pl_mach;
	rename net_vl_open_asset_trans		fcapopen_trans;
	rename net_vl_close_asset_trans		fcapclose_trans;
	rename net_vl_open_asset_oth		fcapopen_oth;
	rename net_vl_close_asset_oth		fcapclose_oth;
	rename grss_vl_open_asset_land 		grossopening_land;
	rename grss_vl_close_asset_land		grossclosing_land;
	rename grss_vl_open_asset_building	grossopening_building;
	rename grss_vl_close_asset_building	grossclosing_building;
	rename grss_vl_open_asset_comp		grossopening_comp;
	rename grss_vl_close_asset_comp		grossclosing_comp;
	rename grss_vl_open_asset_pl_mach 	grossopening_pl_mach;
	rename grss_vl_close_asset_pl_mach	grossclosing_pl_mach;
	rename grss_vl_open_asset_trans		grossopening_trans;
	rename grss_vl_close_asset_trans	grossclosing_trans;
	rename grss_vl_open_asset_oth		grossopening_oth;
	rename grss_vl_close_asset_oth		grossclosing_oth;

	cap rename schcode scheme;

	keep scheme nic_4d nic_5d stcode grsale materials  year_accounting_start
	grossopening* grossclosing* 
	distcode inityr ruralurbancode fcapopen* fcapclose* mult 
	owncode opclcode permid rmstcl rmstop invopen invclose year item_grss_sale_prod* item_sold_prod_item*
	contactshare laborcost wages prodworkers prodworkersday emp empday;

	#delimit cr
	*** Extract state code from the ID 
	gen state	= substr(permid,-3,2)
	destring state,replace force // as of today, there are a few that have no statecode with this method. It is probably due to typos in the firm id. Maybe we can restore them at some point. for now just keep missing
	* discussion with Johaness is that we can get the state and district by merging the cross sectional data with the panel
	* note also that with this method of usng the whole factor-id, it means that when india introduced new states, that created artificial break in the factory id series
	* there might be a way to correct for that --> check that later 

	*** Clean a bit factory id 
	rename permid fid 
	gen numids=fid
	replace numids=subinstr(numids, "F","7",.) if length(fid)==7
	replace numids=subinstr(numids, "-","9",.) if year==1999
	replace numids=subinstr(numids, "F","6",.)
	replace numids=subinstr(numids, "B","2",.)
	replace numids=subinstr(numids, "E","5",.)
	gen numid = numids
	destring numid, replace
	order numid, after(fid)

	* Reorder
	order year numid stcode state distcode nic_4d nic_5d ruralurbancode mult opclcode owncode inityr

	* Fix year and save
	replace year = year - 1

	*** Some additional cleaning coming from Boehm and Oberfield QJE 

	// check for duplicates. drop those with start year equal to 0, or 0 months operation
	duplicates tag fid year, generate(tg)
	drop if (tg>0) & (inityr==0)
	gen year_a = substr(year_accounting,-3,.)
	destring year_a,replace
	drop if (tg>0) & (year_a==0)

	* the rest are true duplicates --> keep the first one 
	gsort fid year -mult
	by fid year: keep if _n==1
	drop tg 


	/*
		   // check for duplicates. right now, if there are multiple fid's but for each
		   // only one active+returned fid (A12=1), then delete the non-active ones
		   duplicates tag FID, generate(tg)
		   drop if (tg>0) & (A12>1)
		   drop tg
	*/

	// age
	// B06 is the year of initial production, but it is not clean
	// use most common B06 within numid, and earlier one if there
	// are multiple modes.
	* use first year in the data when missing 
	egen fyear 		= min(year) ,by(numid)
	replace inityr	= fyear if inityr==0
	bysort numid (year): egen yoip=mode(inityr), minmode
	gen age=year-inityr
	replace age=100 if age>100

	drop inityr fyear
}

* ----------------------------------------------------------------------------
* States and districts consolidation
* ----------------------------------------------------------------------------
{
	gen permid = numid 

	gen original_state_code_brian=stcode
	gen newcodes=(year>=2000)

	**** FIX WRONG DISTRICT CODES DUE TO TYPOS IN ENTRY OR IDENTIFIABLE MISTAKES
	do "$code_asi/fix_typos_and_mistakes.do"

	* Merge a couple states together that were separated mid-sample. This
	* is already done in the district crosswalk only for 1993 to 1999, so the same is applied here

	replace stcode = 5 if (stcode==34 & inrange(year,1993,1998)) // Jharkand -> Bihar
	replace stcode = 13 if (stcode==35 & inrange(year,1993,1998)) // Chattisgarh -> Madhya Pradesh
	replace stcode = 25 if  (stcode==36 & inrange(year,1993,1998)) // Uttaranchal -> Uttar Pradesh

	* Merge in concorded state and district codes from NSS
	merge m:1 stcode distcode year using "$source/crosswalk_brian_merged.dta", ///
		keepusing(district state state_name district_name) gen(crosswalk_merge) keep(1 3)

	* Note that the ASI contains more districts than the NSS, which is most apparent
	* in 2002, 2003, 2006, and 2008. I think our only option is to assume that 
	* these are unchanging over time, and just impute them from the ASI districts.
	replace district = distcode if mi(district) & year <= 2009
	replace district = . if year > 2009


	*******
	label drop _all

	drop stcode
	rename state stcode

	sort stcode (state_name)
	sort year original_state_code_brian stcode

	bys stcode (state_name): replace state_name=state_name[_N]
	bys stcode district (district_name): replace district_name=district_name[_N]
	bys year original_state_code_brian (stcode): replace stcode=stcode[1]
	bys year original_state_code_brian (stcode): replace state_name=state_name[1]


	bys newcodes original_state_code_brian (stcode) : replace stcode=stcode[1]
	bys newcodes original_state_code_brian (stcode) : replace state_name=state_name[1]

	* FIX MATCHES NOT ACCOUNTED FOR IN CROSSWALK
	do "$code_asi/fix_matches_not_accounted.do"

	* New state, Telangana (36), was added in 2012-2013 year. Add this manually.
	* Also set missing state code name to "Missing"
	replace state_name = "Telangana" if stcode == 36
	replace state_name = "Missing" if stcode == .
	* Update labels for state code
	labmask stcode, values(state_name)

	* at this stage drop the few obs with missing statecode 
	drop if stcode ==.


	*** In the raw data, how often a permid has a different state?
	sort permid year 
	by permid: gen d = stcode!=stcode[_n-1] if _n>1
	egen change = max(d),by(permid)
	ta change // 70% of the time ... WTF?????
	ta year if change==1 // no clear pattern 
	ta stcode if change==1 // no clear pattern

	*** For plants with multiple years, see if there are only one year with a wrong info surrounded by correct info --> in this case, change the middle 
	sort permid year 
	by permid: replace stcode = stcode[_n-1] if stcode[_n-1]==stcode[_n+1] & _n>1 // 76k changes

	* recheck if we reduced the number of weird cases 
	drop d change
	sort permid year 
	by permid: gen d = stcode!=stcode[_n-1] if _n>1
	egen change = max(d),by(permid)
	ta change // 25% of the time --> better but still really high 

	ta state_name if change==1 // no clear pattern
	order permid year state_name stcode

	*** At this level we can only take the mode. Inspecting manually, for establishments that appear often this is fine (there is usually one year where the state differ)
	* for establishment with only two obs, the mode won't help much ... use as a rule to take the latest obs 
	bysort permid: egen TEMP=mode(stcode)
	replace stcode = TEMP if TEMP == . 
	* only 51k have a problem of multiple modes --> in this case take the lastest
	gsort permid -year
	by permid: replace stcode = stcode[_n-1] if _n>1 & TEMP==.	
	drop TEMP

	*** Do a first cleaning of industry where we exploit the panel dimension within each classification
	* nic_4d is actually never defined --> use nic_5d 
	gen nic_4	= floor(nic_5d/10)
	replace nic_4 = nic_4d if nic_4 ==. // 2,300 obs 
	drop nic_4d

	* assign modal. When multiple take the biggest 
	* for industry code 1998 
	gen nic98_4 = nic_4 if year >= 1998 & year <= 2003 
	bysort numid: egen TEMP=mode(nic98_4), maxmode
	replace nic98_4 = TEMP if year >= 1998 & year <= 2003 
	drop TEMP


	* for industry code 2004
	gen nic04_4 = nic_4 if year >= 2004 & year <= 2007
	bysort numid: egen TEMP=mode(nic04_4), maxmode
	replace nic04_4 = TEMP if year >= 2004 & year <= 2007
	drop TEMP

	* for industry code 2008
	gen nic08_4 = nic_4 if year >= 2008
	bysort numid: egen TEMP=mode(nic08_4), maxmode
	replace nic08_4 = TEMP if year >= 2008
	drop TEMP 
	save "$output/asi9815", replace

}


* ----------------------------------------------------------------------------
* Create unique nic-4 digit (04 classification) per firm 
* ----------------------------------------------------------------------------
{
	*** 1. convert the 2008 into 2004 code 
	use "$output/asi9815", replace	
 	merge m:1 nic08_4 using "$source/nic08_to_04",update 
	drop if _m==2
	drop _m
	drop if nic04_4==. & year>=2008 // these are nic08 non manufacturing that we could not match--> do not care 

	* We can now assign the main 04 code to firms from 2004 to 2014
	* Use the "real" code when possible (ie fill forward when the permid exist after 2008)
	sort permid year
	* we have already assign one unique code for the period 04-07 --> we can use the first row for a given permid
	* for firms that exist before 2008 this will automatically use the "true" nic04 
	by permid: replace nic04_4 = nic04_4[_n-1] if nic04_4[_n-1] <. 

	*** 2. readjust a bit the 04 classification for merge with 98 classification	
	gen nic04_4am = 1549 if nic04_4 == 1513
	replace nic04_4am = 1711 if nic04_4 == 1713
	replace nic04_4am = 1712 if nic04_4 == 1714
	replace nic04_4am = 1722 if nic04_4 == 1725
	replace nic04_4am = 1729 if nic04_4 == 1724
	replace nic04_4am = 2929 if nic04_4 == 2926
	forval i =1/9{
		replace nic04_4am = 2710 if nic04_4 == 271`i'
	}
	replace nic04_4am = nic04_4 if nic04_4am==.
	drop nic04_4 
	*** 3. Convert all the 98 into 04 
 	merge m:1 nic98_4 using "$source/nic04_4_to_nic98_4",update 

	drop if _m==2
	drop _m

	*** 4. Assign the main 04 to firms from 1998 to 2014 
	* backfill to use the real code 
	* this will use the real code for the year 1998-2004
	* this will also ensure that one firm only has one code 
	gsort permid -year 
	by permid: replace nic04_4am = nic04_4am[_n-1] if nic04_4am[_n-1] <. 

	*** Check that no nic04 modified is missing 
	ta year if nic04_4am==.
	ta nic98_4 if nic04_4am==.

	drop if nic04_4am==. & year>=2002 // these are nic98 non manufacturing that we could not match--> do not care 

	*** Do some cleaning with the nic
	drop nic98_4 nic08_4 
	rename nic04_4am nic04_perm 

	save "$output/nic98_4_to_nic98_4", replace
}			

* ----------------------------------------------------------------------------
* Create unique nic-4 digit (08 classification) per firm 
* ----------------------------------------------------------------------------
{
	*** 1. Assign nic08 using the firm last value if possible. Do the same for nic04
	use "$output/nic98_4_to_nic98_4", replace

	*** Recreate the time-varying definition for merge with permanent 08 classification
	* assign modal. When multiple take the biggest 
	* for industry code 1998 
	gen nic98_4 = nic_4 if year >= 1998 & year <= 2003 
	bysort numid: egen TEMP=mode(nic98_4), maxmode
	replace nic98_4 = TEMP if year >= 1998 & year <= 2003 
	drop TEMP


	* for industry code 2004
	gen nic04_4 = nic_4 if year >= 2004 & year <= 2007
	bysort numid: egen TEMP=mode(nic04_4), maxmode
	replace nic04_4 = TEMP if year >= 2004 & year <= 2007
	drop TEMP

	* for industry code 2008
	gen nic08_4 = nic_4 if year >= 2008
	bysort numid: egen TEMP=mode(nic08_4), maxmode
	replace nic08_4 = TEMP if year >= 2008
	drop TEMP 	

	* nic 08
	gsort permid -year
	by permid: replace nic08_4 = nic08_4[_n-1] if nic08_4[_n-1] <.

	* nic 04
	gsort permid -year
	by permid: replace nic04_4 = nic04_4[_n-1] if nic04_4[_n-1] <.


	*** Now need to use crosswalk table 
	// Start with nic98 --> nic04 	
	merge m:1 nic98_4 using "$source/nic04_4_to_nic98_4_modif",nogen keep(1 3)

	* 16 not matched not sure why--> adjust manually 
	replace nic04_4am = 2330 if nic98_4==2330
	replace nic04_4am = 9302 if nic98_4==9302

	// Nic04 --> nic08
	* a. Adjust the existing nic-04 
	replace nic04_4am	= 1549 		if nic04_4==1513
	replace nic04_4am	= 2211 		if nic04_4==2213
	replace nic04_4am	= 2929 		if nic04_4==2926
	replace nic04_4am	= nic04_4 	if nic04_4am==.

	ta year if nic04_4am ==. // at this stage ALL observations have a nic-04 up to 2008 

	* b. merge with the crosswalk with nic08 
	drop nic04_4
	gen nic04_4 = nic04_4am 
	merge m:1 nic04_4 using "$source/nic04_4_to_nic08_4_modif",nogen keep(1 3)
	replace nic08_4am	= nic08_4 	if nic08_4am==.

	ta year if nic08_4am==. // only seven obs do not have a nic08 
	replace nic08_4am= 9601 if nic04_4am==9302 
	replace nic08_4am= 2410 if nic04_4am==1429 
	replace nic08_4am= 8810 if nic04_4am==8532 
	replace nic08_4am= 9602 if nic04_4am==9302 

	// Create one unique nic4 08classication by using the latest code 
	* 1. extract the mode for comparison later 
	bysort numid: egen nic4_mode=mode(nic08_4am), maxmode

	* 2. use the lastest code available 
	gsort permid -year
	by permid : replace nic08_4am = nic08_4am[1]

	* take the mode 
	bysort numid: egen TEMP=mode(nic08_4am), maxmode
	replace nic08_4am = TEMP 
	drop TEMP 

	* how often the two are different?
	count if nic08_4am !=nic4_mode // 90k

	*** Drop 4 digit that are actually 2 digit (will be impossible to decide if they are treated)
	*gen DROP = floor(nic08_4am/100)*100 == nic08_4am
	*drop if DROP ==1 // 5% of the sample
	*drop DROP 

	*** Identify manufacturing 
	gen nic08_2 = floor(nic08_4am/100) 
	keep if nic08_2>=10 & nic08_2<=33	
	/*
		   for an example of the madness in ASI look at: 
		   br year nic* if permid ==991036	
	*/	

	*** Do a bit of cleaning 
	drop nic98* nic04_4 nic08_4 
	drop nic4_mode nic04_4am
	drop nic_4
	rename nic08_4am nic08_perm 

	save "$output/asi9815_nic_invariant", replace

}
*

*** Clean the data based on cost share
{
	use "$output/asi9815_nic_invariant", replace

	*** Drop negative and missing 
	foreach var of varlist fcapopen_total fcapclose_total emp  ///
		grsale materials laborcost {
		drop if `var' == . | `var'==0 | `var'<0

	}

	*** Clear out outliers in terms of cost shares
	// Wages
	gen wage_share = laborcost / grsale

	// Materials
	gen materials_share = materials / grsale

	// Employment -- follows Allcott et. al,
	gen employment_share = emp * 1000 / grsale
	drop if employment_share > 1

	* Drop shares that are absurb (ideally we would also be able to do that with cost of capital)
	drop if wage_share+materials_share>2
}


*** Deflate variables
{
	*** Bring nic87 classification 
	capture drop nic04_4
	gen nic04_4 = nic04_perm
	merge m:1 nic04_4 using "$source/nic_04_87_4d_composite",nogen keep(1 3)

	* Merge in deflators
	gen nic3digit = nic387
	merge m:1 nic3digit year using "$deflators/Final_Input_Deflator", keep(1 3) nogen // the only nic3 that are not matched are the missing nic04 that are not real manufacturing we have no nic87 in the correspondance table 
	merge m:1 nic3digit year using "$deflators/Final_Output_Deflator.dta", keep(1 3) nogen
	merge m:1 year using "$deflators/Natl_GDP_Deflator.dta", keep(3) nogen
	merge m:1 year using "$deflators/Capital_Deflator.dta", keep(3) nogen

	* Deflate variables
	gen grsale_defl 			= grsale / output_deflator * 100
	gen materials_defl 			= materials / input_deflator * 100
	gen fcapopen_total_defl 	= fcapopen_total / capital_deflator
	gen fcapclose_total_defl 	= fcapclose_total / capital_deflator
	gen K_defl 					= (fcapclose_total_defl + fcapopen_total_defl) / 2 // Average of book value
	gen laborcost_defl 			= laborcost / gdp_defl_natl

	* Need value added for TFP estimation
	gen va_defl 				= grsale_defl - materials_defl
	gen va						= grsale - materials_defl

	* Change year back to original
	* drop year
	* rename year_end year

	*** Create marginal product variables

	* Capital
	*gen mpk_yk = grsale_defl / fcap_defl
	gen K_n			= (fcapclose_total + fcapopen_total) / 2
	gen mpk_yk_n 	= grsale / (fcapclose_total + fcapopen_total) / 2

	* ------------------------------------------------------------------------
	* Miscellaneous clean up
	* ------------------------------------------------------------------------

	* drop permid that are more than 5 years apart 
	sort permid year
	by permid: gen diff = year-year[_n-1]
	egen mdiff	= max(diff),by(permid)

	* drop all the obs after it reappears with such a long lag?
	gen year_reappear = year if diff >=5
	*drop if year >=year_reappear


	*** Take logs 
	foreach var in K_n {
		gen l`var' = log(`var')
	}	

	*** Round multiple for regressions 
	replace mult=round(mult)

	save "$output/asi9815_nic_invariant_02", replace

}	


	
*** Merge everything 
{
	// Program interquartile clean
	capture program drop inter_replace
	program define inter_replace
		sum `1',d
		replace `1'=(r(p50)-`2'*(r(p75)-r(p25))) if `1'<(r(p50)-`2'*(r(p75)-r(p25)))&`1'~=.
		replace `1'=(r(p50)+`2'*(r(p75)-r(p25))) if `1'>(r(p50)+`2'*(r(p75)-r(p25)))&`1'~=.
	end	
	capture program drop inter_trim
	program define inter_trim
		sum `1',d
		replace `1'=. if `1'<(r(p50)-`2'*(r(p75)-r(p25)))&`1'~=.
		replace `1'=. if `1'>(r(p50)+`2'*(r(p75)-r(p25)))&`1'~=.
	end	


	use "$asiclean/asi9815_nic_invariant_02",clear

	* merge with prowess 
	merge m:1 nic08_perm using "$source/FDI_Restrictions_NIC08_4_prowess", keep(1 3) // all nic in prowess are matched in ASI 

	* merge with ASI 
	gen prowess = _m==3
	drop _m

	* bring fdi from original data using nic08 
	merge m:1 nic08_perm using "$source/FDI_Restrictions_NIC08_4_weight",nogen keep(1 3) // all FDI are matched 

	* bring fdi from original data using nic04 
	merge m:1 nic04_perm using "$source/FDI_Restrictions_NIC04_4_weight",nogen keep(1 3) // all FDI are matched 

	*** Compute Y/K and trim outliers 
	gen nic04_3		= floor(nic04_perm/1000)
	gen nic04_2		= floor(nic04_perm/100)	
	gen nic08_3		= floor(nic08_perm/1000)

	gen mpk	= grsale / K_n

	* clean at the 4 digit level (use 5 times the interquantile): nb: I tried cleaning just at the 2 digit but the outliers are still massive even when trimming at 5%
	gen mpk_ct5_ind4 = . 
	gen mpk_cw5_ind4 = . 
	gen mpk_ct4_ind4 = . 
	gen mpk_cw4_ind4 = . 
	gen mpk_ct3_ind4 = . 
	gen mpk_cw3_ind4 = . 

	gen mpk_t5_ind4 = . 
	gen mpk_w5_ind4 = . 
	gen mpk_t10_ind4 = . 
	gen mpk_w10_ind4 = . 

	egen ind = group(nic04_perm)
	sum ind,d
	forval i=1/`r(max)'{	
		forval A=1/6{
			gen temp`A' = mpk if ind==`i'
		}
		// 5 times the interquartile 
		inter_replace temp1 5 
		replace mpk_cw5_ind4 = temp1 if ind==`i'
		inter_trim temp2 5 
		replace mpk_ct5_ind4 = temp2 if ind==`i'
		// 4 times the interquartile 
		inter_replace temp3 4 
		replace mpk_cw4_ind4 = temp3 if ind==`i'
		inter_trim temp4 5 
		replace mpk_ct4_ind4 = temp4 if ind==`i'
		// 3 times interquartile
		inter_replace temp5 3 
		replace mpk_cw3_ind4 = temp5 if ind==`i'
		inter_trim temp6 5 
		replace mpk_ct3_ind4 = temp6 if ind==`i'
		drop temp*

		// trim 
		gen temp = mpk if ind==`i'
		trim_var temp 5
		replace mpk_t5_ind4 = temp_t5 if ind==`i'
		trim_var temp 10
		replace mpk_t10_ind4 = temp_t10 if ind==`i'
		* winsor 
		winsor temp 5
		replace mpk_w5_ind4 = temp if ind==`i'
		drop temp*
		gen temp = mpk if ind==`i'
		winsor temp 10
		replace mpk_w10_ind4 = temp if ind==`i'
		drop temp*
	}

	* clean at the 3 digit level (use 5 times the interquantile)
	gen mpk_ct5_ind3 = . 
	gen mpk_cw5_ind3 = . 
	gen mpk_ct4_ind3 = . 
	gen mpk_cw4_ind3 = . 
	gen mpk_ct3_ind3 = . 
	gen mpk_cw3_ind3 = . 


	gen mpk_t5_ind3 = . 
	gen mpk_w5_ind3 = . 	
	gen mpk_t10_ind3 = . 
	gen mpk_w10_ind3 = . 	

	*** clean across industries 
	gen mpk_ct5_ind0 = . 
	gen mpk_cw5_ind0 = . 
	gen mpk_ct4_ind0 = . 
	gen mpk_cw4_ind0 = . 
	gen mpk_ct3_ind0 = . 
	gen mpk_cw3_ind0 = . 

	forval A=1/6{
		gen temp`A' = mpk 
	}
	// 5 times the interquartile 
	inter_replace temp1 5 
	replace mpk_cw5_ind0 = temp1  
	inter_trim temp2 5 
	replace mpk_ct5_ind0 = temp2 
	// 4 times the interquartile 
	inter_replace temp3 4 
	replace mpk_cw4_ind0 = temp3  
	inter_trim temp4 5 
	replace mpk_ct4_ind0 = temp4  
	// 3 times interquartile
	inter_replace temp5 3 
	replace mpk_cw3_ind0 = temp5  
	inter_trim temp6 5 
	replace mpk_ct3_ind0 = temp6  
	drop temp*


	*** Construct pre-shock 
	gen mpk1 	= mpk 
	gen mpk2	= mpk_ct5_ind4
	gen mpk3	= mpk_cw5_ind4
	gen mpk4	= mpk_ct4_ind4
	gen mpk5	= mpk_cw4_ind4
	gen mpk6	= mpk_ct3_ind4
	gen mpk7	= mpk_cw3_ind4

	gen mpk8	= mpk_ct5_ind3
	gen mpk9	= mpk_cw5_ind3
	gen mpk10	= mpk_ct4_ind3
	gen mpk11	= mpk_cw4_ind3
	gen mpk12	= mpk_ct3_ind3
	gen mpk13	= mpk_cw3_ind3

	gen mpk14	= mpk_ct5_ind0
	gen mpk15	= mpk_cw5_ind0
	gen mpk16	= mpk_ct4_ind0
	gen mpk17	= mpk_cw4_ind0
	gen mpk18	= mpk_ct3_ind0
	gen mpk19	= mpk_cw3_ind0


	* Identify establishments that will participate in the actual estimation 
	egen minyear 	= min(year),by(permid)
	egen maxyear 	= max(year),by(permid)
	gen sample		= minyear<=2001 & maxyear>=2002 // roughly half the total sample

	forval i =1/3{
		gen temp	= mpk`i' if year<=2001 & sample == 1
		egen temp2	= mean(temp),by(permid)
		egen med04	= median(temp2),by(nic04_perm)
		egen med08	= median(temp2),by(nic08_perm)
		gen high_mpk`i'_nic04	= temp2>=med04 if sample == 1 & mpk`i'<.
		gen high_mpk`i'_nic08	= temp2>=med08	if sample == 1 & mpk`i'<.
		drop med* temp*
	}

	// Three type of treatment: using 08, 04 classification and prowess 
	* Prowess 
	gen shockP		= year>fdi_04
	gen shockPw		= shock*FDIw

	* ASI: 08 
	gen shock08		= year>fdi_nic08
	gen shock08w	= (year>fdi_nic08) * wasi_nic08
	recode shock08w . = 0

	* ASI: 04 
	gen shock04		= year>fdi_nic04
	gen shock04w	= (year>fdi_nic04) * wasi_nic04
	recode shock04w . = 0

	*** Define fixed effects 
	egen nic08_2yr		= group(year nic08_2)
	egen nic04_2yr		= group(year nic04_2)

	egen nic08_3yr		= group(year nic08_3)
	egen nic04_3yr		= group(year nic04_3)

	* define manufacturing in nic04 definition 
	gen manuf04			= nic04_2>=15 & nic04_2<=39

	*** State code 
	egen stateyr		= group(state year)

	*** Log level 
	forval i =1/19{
		gen lmpk`i' = log(mpk`i')
	}
	rename (grsale) (sale)
	rename (grsale_defl) (sale_defl)

	foreach var in sale emp wages laborcost sale_defl laborcost_defl va va_defl prodworkers empday {
		gen l`var' = log(`var')		
	}

	*** Use one high definition and one shock 
	gen shock04w_high = shock04w*high_mpk3_nic04

	*** Readjust age 
	replace age = 0 if age <0

	*** Pre-reform size 
	gen temp	= K_n if year<=2001 
	egen size	= mean(K_n),by(permid)
	capture drop nic04_4
	gen nic04_4 = floor(nic04_perm)
	forval i=2/4{
		egen size`i'q4		= xtile(size),nq(4) by(nic04_`i')
		egen size`i'q4yr	= group(size`i'q4 year) 
	}

	save "$asiclean/asi9815_nic_invariant_03", replace
}
*

	// Merge everything 
	use "$output/asi9815_nic_invariant_03", replace	
	* bring dereservation
	replace nic04_4 = nic04_perm
	merge m:1 nic04_4 using "$source/dereservation_nic04",nogen keep(1 3)
	gen dereserv	= (maxyear>=year)
	merge m:1 nic04_4 year using "$source/tariff_nic04_year",nogen keep(1 3)

	*fill in post 2010 for tariffs
	capture drop temp*
	foreach var in output_tariff input_tariff { 
		bysort nic04_4: egen temp = mean(`var') if year==2010
		bysort nic04_4: egen temp2=mean(temp)
		replace `var' =temp2 if year>=2010
		drop temp*
	}
	
	*fill in missing tariff information 
	foreach var in  input_tariff output_tariff { 
		egen T = mean(`var'*mult) ,by(nic04_3 year)
		egen denom=total(mult), by(nic04_3 year)
		replace `var' = T/denom if `var' == .
		egen T2 = mean(`var'*mult) ,by(nic04_2 year)
		egen denom2=mean(mult), by(nic04_2 year)
		replace `var' = T2/denom2 if `var' == .
				
		gen temp=`var' if year==2010
		bysort nic04_4: egen temp2=max(temp)
		replace `var'=temp2 if year>2010
		drop temp* T* denom*
	}	

	save "$output/asi9815_final",replace


