/*

Converts 2013-2014 .TXT data to .dta format.





*/

clear all
set more off
tempvar tmpv

* Set macros
local yr "14"

#delimit ;

infix
str year    1   -   4
str factory_id 5   -   12
str block     13  -   13
str scheme      14  -   14
str ind_code4dig      15  -   18
str ind_code5dig      19  -   23
str rural      24  -   24
str ro_sro     25  -   29
str no_units     30  -   32
str unit_status     33  -   34
str manufacturing_days  35  -   37
str non_manufacturing_days  38  -   40
str working_days   41  -   43
str cost_production  44-57
str export_share 58-60
str  multiplier    61-73
using "$asiraw/1999-2015/201314/old/OASBLA`yr'.TXT";

destring *, replace;

la var  year    "year";
la var  factory_id "Factory Code";
la var  block     "Block code";
la var  scheme      "Scheme code";
la var  ind_code4dig      "Ind. Code as per Frame (4-digit level of NIC-04/NIC-98)";
la var  ind_code5dig      "Ind Code as per Return (5-digit, NIC-04/NIC-98)";
la var  rural      "Rural/Urban code";
la var  ro_sro     "RO/SRO code";
la var  no_units     "No. of units";
la var  unit_status     "Status of Unit";
la var  manufacturing_days  "Number of working days ( Manufacturing days)";
la var  non_manufacturing_days  "Number of working days (Non-Manufacturing days)";
la var  working_days   "Number of working days (Total)";
la var  cost_production  "Cost of Production";
la var  export_share "Share % of products & byproducts directly exported";
la var   multiplier    "Inflation/ multiplierplier factor";

la def scheme 1 "Census" 2 "Sample";
la val scheme scheme;

la def sector 1 "Rural" 2 "Urban";
la val rural sector;

la def status
    1  "Open"
    2  "Closed"
    3  "NOP"
    4  "Deleted (found non-existent within 3 years)"
    5  "Non-response due to closure but in existence and owner/occupier is not traceable"
    6  "Non-response due to non existence now& owner not traceable"
    7  "Non-response due to relevant records are with court/Income tax department etc."
    8  "Non-response due to recalcitrant/refuse to submit the return"
    9  "Non-response due to factory under prosecution in respect of earlier ASI"
    10 "Non-response due to other reasons"
    11 "Deleted (found non-existent after more than 3 years)"
    12 "Deleted due to deregistration"
    13 "Deleted due to out of coverage i.e. Defence,Oil Storage, Technical"
    14 "Deleted due to identical with PSL. No."
    15 "Deleted due to any other reason (Specify)";
la val unit_status status;

compress;

* Merge in districts and new firm ID's;
merge using "$output/blka`yr'_dist.dta";
cap destring district_code  stcode, replace;
cap drop _merge;


save "$output/BLA`yr'.dta", replace;


* BLOCK-B (TO BE FILLED BY OWNERS);

clear;
infix
str year    1-4
str factory_id 5-12
str block 13-13
str ind_code5dig	14-18
str type_organ 19-20
str type_owner 21-21
str year_initial 22-25
str year_accounting_start    26-34
str year_accounting_stop    35-43
str year_months_operation 44-45
str unit_AC 46-46
str unit_ASI_floppy 47-47
str iso_14000 48-48
str multiplier    49-61
using "$asiraw/1999-2015/201314/old/OASBLB`yr'.TXT";

destring *, replace;

la var year "2014";
la var factory_id "Factory Code";
la var block "Block code, Always 'B'";
la var type_organ "Type of organisation(code)";
la var type_owner "Type of ownership(code)";
la var year_initial "year of initial production";
la var year_accounting_start "Accounting year (From)";
la var year_accounting_stop "Accounting year (To)";
la var year_months_operation "Number of months of operation";
la var unit_AC "Does your unit have computerised A/C system? (Yes-1, No-2)";
la var unit_ASI_floppy "Can your unit supply ASI data in Computer Floppy(Yes-1,No-2)";
la var iso_14000 "Whether the unit has ISO Certification, 14000 series";
la var multiplier "Inflation/multiplierplier factor (in 9999.9999 format)";

la def org
    1 "Individual Proprietorship"
    2 "Joint Family (HUF)"
    3 "Partnership"
    4 "Public Limited Company"
    5 "Private Limited Company"
    6 "Government Departmental Enterprise (excluding Khadi,Handloom)"
    7 "Public Corporation by Special Act of Parliament or State Legislature Of PSU"
    8 "Khadi and Village Industries Commission"
    9 "Handlooms"
    10 "Co-operative Society"
    19 "Others (including Trusts, Wakf Boards etc.)";
la val type_organ org;

la def own
    1 "Wholly Central Government"
    2 "Wholly State and/or Local Govt."
    3 "Central Government and State and/or Local Government jointly"
    4 "Joint Sector Public"
    5 "Joint Sector Private"
    6 "Wholly Private Ownership";
la val type_owner own;

la def yesno 1 "Yes" 2 "No";
la val unit_AC yesno;
la val unit_ASI_floppy yesno;

compress;

save "$output/BLB`yr'.dta", replace;


* BLOCK-C (FIXED ASSETS);

clear;
infix
str year    1-4
str factory_id 5-12
str block 13-13
str ind_code5dig	14-18
str s_no    19-20
str grss_vl_open    21-34
str grss_vl_reval    35-48
str grss_vl_add    49-62
str grss_vl_ded    63-76
str grss_vl_close    77-90
str dep_upto_yr_s    91-104
str dep_during_yr    105-118
str adj_sold_disc   119-132
str dep_upto_yr_e   133-146
str net_vl_open   147-160
str net_vl_close   161-174
str multiplier    175-187
using "$asiraw/1999-2015/201314/old/OASBLC`yr'.TXT";

* Values have leading zeros and some have negative values (e.g. "0000-1234"). We remove the leading zeros. ;
* This will allow us to de-string these variables. ;

local varlst "grss_vl_open grss_vl_reval grss_vl_add grss_vl_ded grss_vl_close dep_upto_yr_s dep_during_yr adj_sold_disc dep_upto_yr_e net_vl_open net_vl_close";
foreach x of local varlst {;
    gen `tmpv' = substr(`x',strpos(`x',"-"),.);
    replace `x'=`tmpv' if `tmpv'~="";
    drop `tmpv';
};

destring *, replace;

la var year "2014";
la var factory_id "Factory Code";
la var block "Block code, Always 'C'";
la var s_no "S. No. (to be entered as printed in the schedule)";
la var grss_vl_open "Opening as on ";
la var grss_vl_reval "Due to revaluation";
la var grss_vl_add "Actual addition";
la var grss_vl_ded "Deduction & adjustment during the year";
la var grss_vl_close "Closing as on";
la var dep_upto_yr_s "Up to year beginning ";
la var dep_during_yr "Provided during the year";
la var adj_sold_disc "Adjustment during the year for sold/ discarded.";
la var dep_upto_yr_e "Up to year end";
la var net_vl_open "Opening as on ";
la var net_vl_close "Closing as on";
la var multiplier "Inflation/multiplierplier factor (in 9999.9999 format)";



la def itemC
    1 "Land"
    2 "Building"
    3 "Plant & Machinery"
    4 "Transport equipment"
    5 "Computer equipment including software"
    6 "Pollution Control Equipment"
    7 "Others"
    8 "Sub-total (2 to 7)"
    9 "Capital work in progress"
    10 "Total (1+8+9)";
la val s_no itemC;

compress;


save "$output/BLC`yr'.dta", replace;


* BLOCK-D (WORKING CAPITAL AND LOANS);

clear;
infix
str year    1-4
str factory_id 5-12
str block 13-13
str ind_code5dig 14-18
str s_no    19-20
str opening    21-34
str closing    35-48
str multiplier    49-61
using "$asiraw/1999-2015/201314/old/OASBLD`yr'.TXT";

local varlst "opening closing";
foreach x of local varlst {;
    gen `tmpv' = substr(`x',strpos(`x',"-"),.);
    replace `x'=`tmpv' if `tmpv'~="";
    drop `tmpv';
};
destring *, replace;

la var year "2014";
la var factory_id "Factory Code";
la var block "Block code, Always 'D'";
la var s_no "S. No. (to be entered as printed in the schedule)";
la var opening "Opening (Rs.)";
la var closing "Closing (Rs.)";
la var multiplier "Inflation/multiplierplier factor (in 9999.9999 format)";

la def itemD
    1 "Raw Materials & Components and Packing materials"
    2 "Fuels & Lubricants"
    3 "Spares, Stores & Others"
    4 "Sub-total (1 to 3)"
    5 "Semi-finished goods/work in progress"
    6 "Finished goods"
    7 "Total inventory ( 4 to 6)"
    8 "Cash in Hand in Hand & at Bank"
    9 "Sundry Debtors"
    10 "Other current assets"
    11 "Total current assets (7 to 10)"
    12 "Sundry Creditors"
    13 "Over draft, cash credit, other short Terms loan from Banks & other financial Institutions"
    14 "Other current liabilities"
    15 "Total current liabilities (12 to 14)"
    16 "Working capital (11 minus 15)"
    17 "Outstanding loans (excluding Interest but including deposits)";
la val s_no itemD;

compress;


save "$output/BLD`yr'.dta", replace;


* BLOCK-E (EMPLOYMENT AND LABOUR COST);

clear;
infix
str year    		1-4
str factory_id 		5-12
str block 			13-13
str ind_code5dig 	14-18
str s_no    		19-20
str totday    		37-46
str avg_emp    		47-54
str wages    		65-78
str bonus   		79-92
str insurance   	93-106
str welfare   		107-120
str multiplier    	121-133
using "$asiraw/1999-2015/201314/old/OASBLE`yr'.TXT";

destring *, replace;
compress;
save "$output/BLE`yr'.dta", replace;


* BLOCK-F (OTHER EXPENSES);

clear;
infix
str year    1-4
str factory_id 5-12
str block 13-13
str ind_code5dig 14-18
str work_others  19-32
str repair_building 33-46
str repair_other 47-60
str expenses_op  61-74
str expenses_nop  75-88
str insurance  89-102
str rent_fx_ast  103-116
str expenses_total  117-130
str rent_buildings  131-144
str rent_land  145-158
str interest 159-172
str resale_purch 173-186
str multiplier    187-199
using "$asiraw/1999-2015/201314/old/OASBLF`yr'.TXT";

destring *, replace;

la var year "2014";
la var factory_id "Factory Code";
la var block "Block code, Always 'F'";
la var work_others "Work done by others ";
la var repair_building "Repair & maintenance of Building";
la var repair_other "Repair & maintenance of Other fixed assets";
la var expenses_op "Operating expenses";
la var expenses_nop "Non-operating expenses ";
la var insurance "Insurance Charges";
la var rent_fx_ast "Rent paid for Plant & Machinery and other Fixed assets ";
la var expenses_total "Total expenses (1 to 6)";
la var rent_buildings "Rent paid for Buildings";
la var rent_land "Rent paid for land on lease or royalties on mines, quarries etc.";
la var interest "Interest paid ";
la var resale_purch "Purchase value of goods sold in the same condition as purchased";
la var multiplier "Inflation/multiplierplier factor (in 9999.9999 format)";

compress;

save "$output/BLF`yr'.dta", replace;


* BLOCK-G (OTHER OUTPUT/RECEIPTS);

clear;
infix
str year    1-4
str factory_id 5-12
str block 13-13
str ind_code5dig 14-18
str inc_services  19-32
str stk_semfinish  33-46
str gen_electric  47-60
str construct_own  61-74
str resale_balanc  75-88
str rent_earned  89-102
str total_reciepts  103-116
str rent_received_building  117-130
str rent_received_land  131-144
str interest_received 145-158
str resale_sell 159-172
str tot_subsidy 173-186
str multiplier    187-199
using "$asiraw/1999-2015/201314/old/OASBLG`yr'.TXT";

destring *, replace;

la var year "2014";
la var factory_id "Factory Code";
la var block "Block code, Always 'G'";
la var inc_services "Income from services";
la var stk_semfinish "Variation in stock of semi-finished goods";
la var gen_electric "Value in electricity generated and sold.";
la var construct_own "Value of own construction";
la var resale_balanc "Net balance of goods sold in the same condition as purchased";
la var rent_earned "Rent received for Plant & Machinery and other fixed assets";
la var total_reciepts "Total receipts (1 to 6)";
la var rent_received_building "Rent received for building";
la var rent_received_land "Rent received for land on lease or royalties on mines, quarries etc.";
la var interest_received "Interest received";
la var resale_sell "Sale value of goods sold in the same condition as purchased";
la var tot_subsidy "Total Subsidies";
la var multiplier "Inflation/multiplierplier factor (in 9999.9999 format)";

compress;

save "$output/BLG`yr'.dta", replace;


* BLOCK-H (INPUT ITEMS - Indigenous items consumed);

clear;
infix
str year    1-4
str factory_id 5-12
str block 13-13
str ind_code5dig 14-18
str s_no    20-21
str item_code    22-28
str item_unit    29-31
str item_quantity    32-45
str item_purchase    46-59
str item_rate_unit    60-73
str multiplier    74-86
using "$asiraw/1999-2015/201314/old/OASBLH`yr'.TXT";

destring *, replace;

la var year "2014";
la var factory_id "Factory Code";
la var block "Block code, Always 'H'";
la var s_no "Sl. No.";
la var item_code "Item code (NPCMS)";
la var item_unit "Unit of quantity (code)";
la var item_quantity "Quantity consumed ";
la var item_purchase "Purchase value (in Rs.)";
la var item_rate_unit "Rate per unit (in Rs.)";
la var multiplier "Inflation/multiplierplier factor (in 9999.9999 format)";

***code the itemcodes into strings directly so that the encoding doesnt get messed up between years ;
lab def slnoH
11  "Other"
12  "TotalBasic"
13  "Chemicals"
14  "Packing"
15  "ElecGen"
16  "ElecPurchase"
17  "OilConsumed"
18  "CoalConsumed"
19  "GasConsumed"
20  "OtherConsumed"
21  "ConsumableStore"
22  "TotalNonBasic"
23  "Total"
24  "UnmetElec"
;
lab values s_no slnoH;
drop if s_no > 24 ;

compress;


save "$output/BLH`yr'.dta", replace;


* BLOCK-I (INPUT ITEMS - Directly imported items only (consumed));

clear;
infix
str year    1-4
str factory_id 5-12
str block 13-13
str ind_code5dig 14-18
str s_no    19-20
str item_code    21-27
str item_unit    28-30
str item_quantity    31-44
str item_purchase    45-58
str item_rate_unit    59-72
str multiplier    73-85
using "$asiraw/1999-2015/201314/old/OASBLI`yr'.TXT";

destring *, replace;

la var year "2014";
la var factory_id "Factory Code";
la var block "Block code, Always 'I'";
la var s_no "Sl. No.";
la var item_code "Item code (NPCMS)";
la var item_unit "Unit of quantity (code)";
la var item_quantity "Quantity consumed ";
la var item_purchase "Purchase value at delivery (in Rs.)";
la var item_rate_unit "Rate per unit (in Rs.) ";
la var multiplier "Inflation/multiplierplier factor (in 9999.9999 format)";

compress;


save "$output/BLI`yr'.dta", replace;


* BLOCK-J (PRODUCTS AND BY-PRODUCTS (Manufactured by the unit));
clear;
infix
str year    1-4
str factory_id 5-12
str block 13-13
str ind_code5dig 14-18
str s_no    19-20
str item_code    21-27
str item_unit    28-30
str item_quantity    31-44
str item_sold    45-58
str item_grss_sale    59-72
str item_exp_exise    73-86
str item_exp_tax    87-100
str item_exp_other   101-114
str item_exp_total   115-128
str item_unit_val   129-142
str item_total_val   143-156
str multiplier    157-169
using "$asiraw/1999-2015/201314/old/OASBLJ`yr'.TXT";

destring *, replace;

la var year "2014";
la var factory_id "Factory Code";
la var block "Block code, Always 'J'";
la var s_no "Sl.No.";
la var item_code "Item code (NPCMS)";
la var item_unit "Unit of quantity (code)";
la var item_quantity "Quantity manufactured";
la var item_sold "Quantity sold ";
la var item_grss_sale "Gross sale value (Rs.)";
la var item_exp_exise "Excise duty (Rs.) ";
la var item_exp_tax "Sales Tax (Rs.) ";
la var item_exp_other "Others  (Rs.) ";
la var item_exp_total "Total (Rs.) ";
la var item_unit_val "Per unit net sale value  (Rs.) ";
la var item_total_val "Ex-factory value of output (Rs.) (12 x 5)";
la var multiplier "Inflation/multiplierplier factor (in 9999.9999 format)";

compress;


save "$output/BLJ`yr'.dta", replace;
