/*
	   Reshapes blocks of 2009-2011 ASI data to wide, merge. 
*/


local small "9 10 11 12 13 14 15"
local mid "0809 0910 1011 1112 1213 1314 1415"
local n : word count `small'

forvalues i=1/`n' {
	clear
	local yr : word `i' of `small'
	local yr_name : word `i' of `mid'

	* -- Category codes, block C (FIXED ASSETS) -- *
	use "$output/BLC`yr'.dta", clear
	
	destring s_no, replace
	
	capture drop cat_code
	gen cat_code = ""

	replace cat_code = "_asset_land" if s_no ==1
	replace cat_code = "_asset_building" if s_no ==2
	replace cat_code = "_asset_pl_mach" if s_no ==3
	replace cat_code = "_asset_trans" if s_no ==4
	replace cat_code = "_asset_comp" if s_no ==5
	replace cat_code = "_asset_polu" if s_no ==6
	replace cat_code = "_asset_oth" if s_no ==7
	replace cat_code = "_asset_sub" if s_no ==8
	replace cat_code = "_asset_cap_wip" if s_no ==9
	replace cat_code = "_asset_total" if s_no ==10

	drop if cat_code == ""	
	save "$output/BLC`yr'.dta", replace

	* -- Category codes, Block D (WORKING CAPITAL AND LOANS) -- *
	use "$output/BLD`yr'.dta", clear

	destring s_no, replace
	capture drop cat_code
	gen cat_code = ""

	replace cat_code = "_cap_li_raw_mat" if s_no ==1
	replace cat_code = "_cap_li_fuels" if s_no ==2
	replace cat_code = "_cap_li_spares" if s_no ==3
	replace cat_code = "_cap_li_sub_inv" if s_no ==4
	replace cat_code = "_cap_li_semi_fin" if s_no ==5
	replace cat_code = "_cap_li_fin" if s_no ==6
	replace cat_code = "_cap_li_tot_inv" if s_no ==7
	replace cat_code = "_cap_li_cash" if s_no ==8
	replace cat_code = "_cap_li_debtor" if s_no ==9
	replace cat_code = "_cap_li_oth_ast" if s_no ==10
	replace cat_code = "_cap_li_cur_ast" if s_no ==11
	replace cat_code = "_cap_li_creditor" if s_no ==12
	replace cat_code = "_cap_li_st_loans" if s_no ==13
	replace cat_code = "_cap_li_oth_lia" if s_no ==14
	replace cat_code = "_cap_li_tot_lia" if s_no ==15
	replace cat_code = "_cap_li_wrk_cap" if s_no ==16
	replace cat_code = "_cap_li_out_lns" if s_no ==17

	drop if cat_code == ""
	save "$output/BLD`yr'.dta", replace

	* -- Category Codes, Block E (Labor Costs) -- *
	use "$output/BLE`yr'.dta", clear

	destring s_no, replace
	capture drop cat_code
	gen cat_code = ""

	replace cat_code = "_emp_ml_con" if s_no ==1
	replace cat_code = "_emp_gm_con" if s_no ==2
	replace cat_code = "_emp_tot_con" if s_no ==3
	replace cat_code = "_emp_cntrct" if s_no ==4
	replace cat_code = "_emp_tot_wrk" if s_no ==5
	replace cat_code = "_emp_sup_man" if s_no ==6
	replace cat_code = "_emp_others" if s_no ==7
	replace cat_code = "_emp_fam" if s_no ==8
	replace cat_code = "_emp_total" if s_no ==9

	drop if cat_code == ""
	save "$output/BLE`yr'.dta", replace

	* -- Category Codes, Block H (Consumption of Domestic Goods) -- *
	use "$output/BLH`yr'.dta", clear

	destring s_no, replace
	capture drop cat_code
	gen cat_code = ""

	replace cat_code = "_id_inp_item1" if s_no ==1
	replace cat_code = "_id_inp_item2" if s_no ==2
	replace cat_code = "_id_inp_item3" if s_no ==3
	replace cat_code = "_id_inp_item4" if s_no ==4
	replace cat_code = "_id_inp_item5" if s_no ==5
	replace cat_code = "_id_inp_item6" if s_no ==6
	replace cat_code = "_id_inp_item7" if s_no ==7
	replace cat_code = "_id_inp_item8" if s_no ==8
	replace cat_code = "_id_inp_item9" if s_no ==9
	replace cat_code = "_id_inp_item10" if s_no ==10
	replace cat_code = "_id_inp_item_o" if s_no ==11
	replace cat_code = "_id_inp_tot_bas" if s_no ==12
	replace cat_code = "_id_inp_chem" if s_no ==13
	replace cat_code = "_id_inp_pack" if s_no ==14
	replace cat_code = "_id_inp_gen_elec" if s_no ==15
	replace cat_code = "_id_inp_pur_elec" if s_no ==16
	replace cat_code = "_id_inp_oil_cons" if s_no ==17
	replace cat_code = "_id_inp_col_cons" if s_no ==18
	replace cat_code = "_id_inp_gas_cons" if s_no ==19
	replace cat_code = "_id_inp_o_fl_cons" if s_no ==20
	replace cat_code = "_id_inp_cons_str" if s_no ==21
	replace cat_code = "_id_inp_tot_nbas" if s_no ==22
	replace cat_code = "_id_inp_total" if s_no ==23
	replace cat_code = "_id_inp_unmet" if s_no ==24

	drop if cat_code == ""

	* Issue with one observation in Block H, 2014, reported multiple
	* item types twice. Dropping them.
	duplicates tag factory_id cat_code, gen(tag)
	capture drop if tag!=0
	capture drop tag

	save "$output/BLH`yr'.dta", replace

	* -- Category codes, Block I (Consumption of Imported Goods) -- *
	use "$output/BLI`yr'.dta", clear

	destring s_no, replace
	capture drop cat_code
	gen cat_code = ""

	replace cat_code = "_co_inp_item1" if s_no ==1
	replace cat_code = "_co_inp_item2" if s_no ==2
	replace cat_code = "_co_inp_item3" if s_no ==3
	replace cat_code = "_co_inp_item4" if s_no ==4
	replace cat_code = "_co_inp_item5" if s_no ==5
	replace cat_code = "_co_inp_item_o" if s_no ==6
	replace cat_code = "_co_inp_total" if s_no ==7

	drop if cat_code == ""
	save "$output/BLI`yr'.dta", replace

	* -- Category codes, Block J (sales) -- *
	use "$output/BLJ`yr'.dta", clear

	destring s_no, replace
	capture drop cat_code
	gen cat_code = ""

	replace cat_code = "_prod_item1" if s_no ==1
	replace cat_code = "_prod_item2" if s_no ==2
	replace cat_code = "_prod_item3" if s_no ==3
	replace cat_code = "_prod_item4" if s_no ==4
	replace cat_code = "_prod_item5" if s_no ==5
	replace cat_code = "_prod_item6" if s_no ==6
	replace cat_code = "_prod_item7" if s_no ==7
	replace cat_code = "_prod_item8" if s_no ==8
	replace cat_code = "_prod_item9" if s_no ==9
	replace cat_code = "_prod_item10" if s_no ==10
	replace cat_code = "_prod_item_o" if s_no ==11
	replace cat_code = "_prod_total" if s_no ==12

	drop if cat_code == ""
	save "$output/BLJ`yr'.dta", replace

	**** Reshape *****
	foreach l in C D H I J {
		use "$output/BL`l'`yr'.dta", clear
		local varlist s_no - multiplier
		reshape wide `varlist', i(factory_id) j(cat_code) string
		save "$output/BL`l'`yr'.dta", replace
	}


	*** Reshape separately employment module 
	use "$output/BLE`yr'", clear

	/*
		   gen cat_code = ""
		   replace cat_code = "_emp_ml_con" if s_no ==1
		   replace cat_code = "_emp_gm_con" if s_no ==2
		   replace cat_code = "_emp_chl_con" if s_no ==3
		   replace cat_code = "_emp_tot_con" if s_no ==4
		   replace cat_code = "_emp_cntrct" if s_no ==5
		   replace cat_code = "_emp_tot_wrk" if s_no ==6
		   replace cat_code = "_emp_sup_man" if s_no ==7
		   replace cat_code = "_emp_others" if s_no ==8
		   replace cat_code = "_emp_fam" if s_no ==9
		   replace cat_code = "_emp_total" if s_no ==10
		   drop if cat_code ==""
	*/
	drop if s_no==.
	local varlist s_no - multiplier

	* Drop duplicates
	g index = _n
	bysort factory_id s_no: gen dup = _N
	drop if dup > 1
	sort index
	drop index dup

	* Reshape, save
	keep totday avg_emp wages bonus insurance welfare factory_id s_no
	reshape wide totday avg_emp wages bonus insurance welfare, i(factory_id) j(s_no) 

	* total 
	egen empday	= rowtotal(totday1 totday2 totday4  totday6 totday7 totday8)
	* normally empday should be equal to totday9, almost always the case (except for three values)
	count if empday==totday9
	local var = "avg_emp"
	egen emp	= rowtotal(`var'1 `var'2 `var'4 `var'6 `var'7 `var'8)

	* production workers
	local var = "totday"
	egen prodworkersday	= rowtotal(`var'1 `var'2 `var'4)
	local var = "avg_emp"
	egen prodworkers	= rowtotal(`var'1 `var'2 `var'4)

	* total wages
	foreach var in wages bonus insurance welfare{
		egen `var'		= rowtotal(`var'1 `var'2 `var'4 `var'6 `var'7 `var'8)
	}
	foreach var in wages bonus insurance welfare{
		egen contractor_`var'	= rowtotal(`var'4)
	}

	* total compensation
	gen laborcost		= wages +bonus +insurance +welfare
	gen contactshare	= (contractor_wages+contractor_bonus+contractor_insurance+contractor_welfare)/laborcost 

	save "$output/BLE`yr'", replace



	**** Merge ****
	use "$output/BLA`yr'", clear
	foreach l in B C D E F G H I J {
		joinby factory_id using "$output/BL`l'`yr'.dta", unmatched(master)
		capture drop s_no*
		drop _merge
		disp "`l'"
	}

	compress
	save "$output/asi`yr_name'.dta", replace

	/*
		   foreach l in A B C D E F G H I J {
		   cap erase "$output/BL`l'`yr'.dta"
		   }
	*/

}




































