


**************************************************************
**** LOAD UPDATED FILE 			  ****************************
**************************************************************

*need the updated file
use "$source/products_traded", clear
gen t = sales_qty
destring sales_qty sales_value, replace force
drop if sales_value==. | sales_value<0 | sales_qty<0 // I checked, it corresponds to "NA" ... 
drop t

local maxyear 2015
keep if year>=1995 & year<=`maxyear'
duplicates drop 
*if reported twice, keep longer report
duplicates tag company_name product_name year products_product_code, gen(tag)
bysort company_name product_name year products_product_code: egen temp=max(ann_rep_months )
drop if tag==1 & ann_rep_months!=temp
drop temp tag

*still some left over, in this case, choose randomly
egen prod_id=group(company_name product_name products_product_code)
duplicates drop company_name product_name products_product_code year, force


/* linearly interpolate missing values (we dont gain much)
egen product_unit = group(company_name product_name sales_unit)
sort product_unit year
by product_unit: replace sales_qty 		= (sales_qty[_n-1]+sales_qty[_n+1])*0.5 if _n>1 & sales_qty==.
by product_unit: replace sales_value 	= (sales_value[_n-1]+sales_value[_n+1])*0.5 if _n>1 & sales_value==.
*/
*get rid of missing values
*drop if sales_qty==. | sales_value==.


destring year, replace
*rename sa_finance1_cocode id
save "$output/traded", replace

*get company names for merge
	use  company_name co_code nic_prod_code using "$source/identity_2020",clear 
	duplicates drop
	merge 1:m company_name using "$output/traded"
	keep if _merge==3
	drop _merge
	
	rename co_code id
	
*** Create nic code 
	tostring nic_prod_code, replace
	// Careful, the five digit nic code is messed up. Sometimes they only report 1 or 2 digit but the zeros might be before or after the reported number
	replace nic_prod_code = "0" + nic_prod_code+"000" if length(nic_prod_code) == 1
	drop if nic_prod_code=="34" | nic_prod_code=="89"
	replace nic_prod_code = nic_prod_code+"000" if length(nic_prod_code) == 2
	
	replace nic_prod_code = nic_prod_code+"00" if length(nic_prod_code) == 3
	
	
	gen n = nic_prod_code
	destring n,replace
	ta product_name_mst if length(nic_prod_code) == 4	
	* ok so here this is all over the place (of course....). Some are raw products (so zero should be first) others are transformed (so zero should be last)
	replace nic_prod_code = "0" + nic_prod_code if length(nic_prod_code) == 4 & (n==1111|n==1112|n==1113|n==1114|n==1118|n==1119|n==1121|n==1124|n==1132|n==1133|n==1135|n==1136|n==1139|n==1140|n==1150|n==1161|n==1162|n==1191|n==1193|n==1199)
	replace nic_prod_code = "0" + nic_prod_code if length(nic_prod_code) == 4 & (n==1210|n==1221|n==1222|n==1223|n==1239|n==1249|n==1252|n==1259|n==1261|n==1271|n==1272|n==1279|n==1282|n==1283|n==1284|n==1286|n==1291|n==1293|n==1299|n==1301)
	replace nic_prod_code = "0" + nic_prod_code if length(nic_prod_code) == 4 & (n==1411|n==1412|n==1491|n==1420|n==1462|n==1463|n==1492|n==1493|n==1499|n==1499|n==1640|n==2302|n==2303|n==2309)
	
	replace nic_prod_code = nic_prod_code + "0" if length(nic_prod_code) == 4 & (n==1030|n==1071|n==1072|n==1073|n==1075|n==1101|n==1200)
	replace nic_prod_code = nic_prod_code + "0" if length(nic_prod_code) == 4 & (n==1312|n==1393|n==1394|n==1399|n==1410|n==1430|n==1512|n==1520|n==2012|n==2021|n==2030|n==2100)
	replace nic_prod_code = nic_prod_code + "0" if length(nic_prod_code) == 4 & (n==2395|n==2410|n==2410|n==2420|n==2513|n==2610|n==2630|n==2640|n==2651|n==2710|n==2790|n==2811|n==2813|n==2825|n==2910)
	replace nic_prod_code = nic_prod_code + "0" if length(nic_prod_code) == 4 & (n==2930|n==3030|n==3240|n==3510|n==3821|n==4510|n==4530|n==4630|n==4722|n==4759|n==4761|n==4921|n==4923|n==5109|n==5210)
	replace nic_prod_code = nic_prod_code + "0" if length(nic_prod_code) == 4 & (n==5224|n==5911|n==6020|n==6130|n==6202|n==6920|n==7100|n==7210|n==7292|n==7293|n==7294|n==7295|n==7299|n==8101|n==8102|n==8104|n==8105|n==8106|n==8107|n==8108|n==8109|n==8911|n==8912|n==8915|n==8919|n==8931|n==8994|n==8996|n==8998|n==8999)

	gen nic2008_4digit = substr(nic_prod_code, 1, 4)
	gen nic2008_5digit = substr(nic_prod_code, 1, 5)

quiet{
**************************************************************
**** CLEAN SALES UNITS 			  ****************************
**************************************************************
*makes sure sales units don't change over time
gen UNIT = sales_unit
*concrete specific conversion
replace sales_qty=sales_qty*2.41 if sales_unit=="'000 cu.metres" & product_name=="READY MIX CONCRETE"
replace sales_unit="Tonnes" if sales_unit=="'000 cu.metres" & product_name=="READY MIX CONCRETE"

*make units homogeneous within companies
*change '000 tonnes = Tonnes
replace sales_qty=sales_qty*1000 if sales_unit=="'000 tonnes"
replace sales_unit="Tonnes" if sales_unit=="'000 tonnes"

// Number
replace sales_qty=sales_qty*100 if sales_unit=="'00 nos"
replace sales_unit="Numbers" if sales_unit=="'00 nos"

replace sales_qty=sales_qty*1000 if sales_unit=="'000 nos"
replace sales_unit="Numbers" if sales_unit=="'000 nos"

replace sales_qty=sales_qty*100000 if sales_unit=="Lakh nos" // Lakh lakh is a unit in the Indian numbering system equal to one hundred thousand  
replace sales_unit="Numbers" if sales_unit=="Lakh nos"

replace sales_qty=sales_qty*1000000 if sales_unit=="Million nos"
replace sales_unit="Numbers" if sales_unit=="Million nos"

// Kilo Litres
replace sales_unit="Kls" if sales_unit=="'000 litres"

replace sales_qty=sales_qty*1000 if sales_unit=="Litres"
replace sales_unit="Kls" if sales_unit=="Litres"

replace sales_qty=sales_qty/1000 if sales_unit=="'000 kls."
replace sales_unit="Kls" if sales_unit=="'000 kls."

replace sales_qty=sales_qty/1000 if sales_unit=="Million litres"
replace sales_unit="Kls" if sales_unit=="Million litres"

replace sales_unit="Kls" if sales_unit=="'000 bulk litres"

replace sales_qty=sales_qty*1000000 if sales_unit=="'000 milli litres"
replace sales_unit="Kls" if sales_unit=="'000 milli litres"

replace sales_unit="Kls" if sales_unit=="Kgs-litres"

replace sales_qty=sales_qty/100 if sales_unit=="Lakh litres"
replace sales_unit="Kls" if sales_unit=="Lakh litres"

replace sales_qty=sales_qty*100000000000 if sales_unit=="Lakh milli litres"
replace sales_unit="Kls" if sales_unit=="Lakh milli litres"

// Tonnes
replace sales_qty=sales_qty*1000 if sales_unit=="Kgs"
replace sales_unit="Tonnes" if sales_unit=="Kgs"

replace sales_qty=sales_qty*1000 if sales_unit=="Bulk kgs"
replace sales_unit="Tonnes" if sales_unit=="Bulk kgs"

replace sales_qty=sales_qty*100000000 if sales_unit=="Lakh kgs"
replace sales_unit="Tonnes" if sales_unit=="Lakh kgs"
replace sales_qty=sales_qty*100000 if sales_unit=="Lakh tonnes"
replace sales_unit="Tonnes" if sales_unit=="Lakh tonnes"
replace sales_unit="Tonnes" if sales_unit=="Tonnes-number"

// Number
replace sales_qty=sales_qty*100000 if sales_unit=="Lakh nos"
replace sales_unit="Numbers" if sales_unit=="Lakh nos"

replace sales_qty=sales_qty*1000 if sales_unit=="'000 nos"
replace sales_unit="Numbers" if sales_unit=="'000 nos"

*IS THIS A MISTAKE?
*replace sales_unit="'000 nos" if sales_unit=="Tonnes-number"
*replace sales_unit="'000 nos" if sales_unit=="'000 pieces"

// Kwh
replace sales_qty=sales_qty/1000 if sales_unit=="'000 kwh"
replace sales_unit="Kwh" if sales_unit=="'000 kwh"

replace sales_unit="Kwh" if sales_unit=="Kw"

replace sales_qty=sales_qty/100000 if sales_unit=="Lakh kwh"
replace sales_unit="Kwh" if sales_unit=="Lakh kwh"

replace sales_qty=sales_qty/1000000 if sales_unit=="Million kwh"
replace sales_unit="Kwh" if sales_unit=="Million kwh"

#delimit ;
local measures  "Ampoules
				Bags
				Bales
				Books
				Bottles
				Boxes
				Cc
				Cans
				Caps
				Carats
				Cards
				Cases
				Containers
				Coils
				Copies
				Crates
				Decimetres
				Doses
				Dozens
				Feet
				Gallons
				Gross
				Hides
				Impression
				Jars
				Kms
				Kcal
				Lbs
				Lines
				Metres
				Packets
				Packs
				Pairs
				Pouches
				Reams
				Reels
				Rolls
				Sachets
				Sets
				Sheets
				Strips
				Tablets
				Tests
				Tubes
				Units
				Vials
				Volumes
				Volts
				Yards";
#delimit cr				
				

foreach meas of local measures {


replace sales_qty=sales_qty*100000 if sales_unit=="Lakh "+lower("`meas'")
replace sales_unit="`meas'" if sales_unit=="Lakh "+lower("`meas'")

replace sales_qty=sales_qty*1000 if sales_unit=="'000 "+lower("`meas'")
replace sales_unit="`meas'" if sales_unit=="'000 "+lower("`meas'")

replace sales_qty=sales_qty*1000000 if sales_unit=="Million "+lower("`meas'") 
replace sales_unit="`meas'" if sales_unit=="Million "+lower("`meas'")
}

//piece
replace sales_qty=sales_qty*1000 if sales_unit=="'000 pieces"
replace sales_unit="Piece" if sales_unit=="'000 pieces"


//core metres
replace sales_qty=sales_qty*1000 if sales_unit=="'000 core metres"
replace sales_unit="Core Metres" if sales_unit=="'000 core metres"

replace sales_qty=sales_qty*100000 if sales_unit=="Lakh core metres"
replace sales_unit="Core Metres" if sales_unit=="Lakh core metres"

replace sales_qty=sales_qty*1000000 if sales_unit=="Million core metres"
replace sales_unit="Core Metres" if sales_unit=="Million core metres"


//Cubic feet
replace sales_qty=sales_qty*1000*0.0283168 if sales_unit=="'000 cu.feet"
replace sales_unit="Cubic metres" if sales_unit=="'000 cu.feet"

replace sales_qty=sales_qty*100000*0.0283168 if sales_unit=="Lakh cu.feet"
replace sales_unit="Cubic metres" if sales_unit=="Lakh cu.feet"

replace sales_qty=sales_qty*1000000*0.0283168 if sales_unit=="Million cu.feet"
replace sales_unit="Cubic metres" if sales_unit=="Million cu.feet"

//Cubic metres
replace sales_qty=sales_qty*1000 if sales_unit=="'000 cu.metres"
replace sales_unit="Cubic metres" if sales_unit=="'000 cu.metres"

replace sales_qty=sales_qty*100000 if sales_unit=="Lakh cu.metres"
replace sales_unit="Cubic metres" if sales_unit=="Lakh cu.metres"

replace sales_qty=sales_qty*1000000 if sales_unit=="Million cu.metres"
replace sales_unit="Cubic metres" if sales_unit=="Million cu.metres"

//Dozen Pairs
replace sales_qty=sales_qty*1000*12 if sales_unit=="'000 dozen pairs"
replace sales_unit="Pairs" if sales_unit=="'000 dozen pairs"

replace sales_qty=sales_qty*100000*12 if sales_unit=="Lakh dozen pairs"
replace sales_unit="Pairs" if sales_unit=="Lakh dozen pairs"

replace sales_qty=sales_qty*1000000*12 if sales_unit=="Million dozen pairs"
replace sales_unit="Pairs" if sales_unit=="Million dozen pairs"

//Horse power
replace sales_qty=sales_qty*1000 if sales_unit=="'000 horse power"
replace sales_unit="Horse power" if sales_unit=="'000 horse power"

replace sales_qty=sales_qty*100000 if sales_unit=="Lakh horse power"
replace sales_unit="Horse power" if sales_unit=="Lakh horse power"

replace sales_qty=sales_qty*1000000 if sales_unit=="Million horse power"
replace sales_unit="Horse power" if sales_unit=="Million horse power"


//Linear metres
replace sales_qty=sales_qty*1000 if sales_unit=="'000 linear metres"
replace sales_unit="Linear Metres" if sales_unit=="'000 linear metres"

replace sales_qty=sales_qty*100000 if sales_unit=="Lakh linear metres"
replace sales_unit="Linear Metres" if sales_unit=="Lakh linear metres"

replace sales_qty=sales_qty*1000000 if sales_unit=="Million linear metres"
replace sales_unit="Linear Metres" if sales_unit=="Million linear metres"


replace sales_qty=sales_qty*1000 if sales_unit=="'000 running metres"
replace sales_unit="Linear Metres" if sales_unit=="'000 running metres"

replace sales_qty=sales_qty*100000 if sales_unit=="Lakh running metres"
replace sales_unit="Linear Metres" if sales_unit=="Lakh running metres"

replace sales_qty=sales_qty*1000000 if sales_unit=="Million running metres"
replace sales_unit="Linear Metres" if sales_unit=="Million running metres"


replace sales_qty=sales_qty*1000*0.3048 if sales_unit=="'000 running feet"
replace sales_unit="Linear Metres" if sales_unit=="'000 running feet"

replace sales_qty=sales_qty*100000*0.3048 if sales_unit=="Lakh running feet"
replace sales_unit="Linear Metres" if sales_unit=="Lakh running feet"

replace sales_qty=sales_qty*1000000*0.3048 if sales_unit=="Million running feet"
replace sales_unit="Linear Metres" if sales_unit=="Million running feet"


//sq metres
replace sales_qty=sales_qty*1000 if sales_unit=="'000 sq.metres"
replace sales_unit="Square metres" if sales_unit=="'000 sq.metres"

replace sales_qty=sales_qty*100000 if sales_unit=="Lakh sq.metres"
replace sales_unit="Square metres" if sales_unit=="Lakh sq.metres"

replace sales_qty=sales_qty*1000000 if sales_unit=="Million sq.metres"
replace sales_unit="Square metres" if sales_unit=="Million sq.metres"

replace sales_qty=sales_qty*1000*0.0929 if sales_unit=="'000 sq.feet"
replace sales_unit="Square metres" if sales_unit=="'000 sq.feet"

replace sales_qty=sales_qty*100000*0.0929 if sales_unit=="Lakh sq.feet"
replace sales_unit="Square metres" if sales_unit=="Lakh sq.feet"

replace sales_qty=sales_qty*1000000*0.0929 if sales_unit=="Million sq.feet"
replace sales_unit="Square metres" if sales_unit=="Million sq.feet"


replace sales_qty=sales_qty*1000*0.01 if sales_unit=="'000 sq.decimetres"
replace sales_unit="Square metres" if sales_unit=="'000 sq.decimetres"

replace sales_qty=sales_qty*100000*0.01 if sales_unit=="Lakh sq.decimetres"
replace sales_unit="Square metres" if sales_unit=="Lakh sq.decimetres"

replace sales_qty=sales_qty*1000000*0.01 if sales_unit=="Million sq.decimetres"
replace sales_unit="Square metres" if sales_unit=="Million sq.decimetres"

replace sales_qty=sales_qty*100000*0.000645 if sales_unit=="Lakh sq.inches"
replace sales_unit="Square metres" if sales_unit=="Lakh sq.inches"

//proof litres
replace sales_qty=sales_qty*100000 if sales_unit=="Lakh proof litres"
replace sales_unit="Proof litres" if sales_unit=="Lakh proof litres"

//proof litres
replace sales_qty=sales_qty*100000 if sales_unit=="Lakh proof kls"
replace sales_unit="Proof kls" if sales_unit=="Lakh proof kls"


}
*
egen num=group(sales_unit)

bysort prod_id: egen temp1=min(num)
bysort prod_id: egen temp2=max(num)
gen diff=temp2-temp1
count if diff!=0 & sales_qty!=. & sales_value!=.

*order id product_name product_name_mst nic2008_4digit nic2008_5digit year sales_unit sales_qty sales_value diff num

*force products by the same company to have the same units over time
tab sales_unit if diff!=0 & sales_qty!=. & sales_value!=.

drop if diff!=0 

gen price=sales_value/sales_qty
gen log_price=log(price)

replace price=. if price<0


*** Product fixed effects	
	egen firm_prod_fe	= group(id sales_unit product_name products_product_code)
	egen prod_year		= group(product_name sales_unit products_product_code year)
	
	
	foreach var in  sales_qty sales_value { 
		gen beta=ann_rep_months/12
		replace `var'=`var'*1/beta
		drop beta
		}
keep UNIT product_name nic2008_4digit products_product_code id year log_price firm_prod_fe sales_qty price sales_unit sales_value prod_id 

save "$output/product_clean",replace


*** Count number of products and probability to add / delete one product
use "$output/product_clean",replace
* identify first and last year of the firm
egen minyear 	= min(year),by(id)
egen maxyear 	= max(year),by(id)
* identify first and last year of the PRODUCT
egen minyear_prod1 	= min(year),by(firm_prod_fe)
egen maxyear_prod1 	= max(year),by(firm_prod_fe)

egen minyear_prod2 	= min(year),by(products_product_code id)
egen maxyear_prod2 	= max(year),by(products_product_code id)

egen minyear_prod3 	= min(year),by(product_name id)
egen maxyear_prod3 	= max(year),by(product_name id)

forval x=1(1)3{
* Consider a product is deleted if max year of product is lower than max year of the firm
gen deletion`x' = maxyear_prod`x'<maxyear
gen addition`x'	= minyear_prod`x'>minyear

}

* nb of product
bys firm_prod_fe year: gen nbprod1 = 1 if _n==1
bys id products_product_code year: gen nbprod2 = 1 if _n==1
bys id product_name year: gen nbprod3 = 1 if _n==1

collapse(sum)nbprod* addition* deletion*,by(id year)
save "$output/product_portfolio",replace

 
*erase traded.dta

