



*** EQUITY: prepare equity data 
{
    use "$source/equity", clear  
    keep shp_cocode company_name shp_date total_equity frgn_promoters_equity fii_equity frgn_venture_cap_equity

    // to be used for merging with final data
	tostring shp_date,replace
	gen date1 = substr(shp_date,1,4)
	gen date2 = substr(shp_date,5,2)
	gen date3 = substr(shp_date,7,2)
	replace shp_date = date1+"-"+date2+"-"+date3
    gen date = date(shp_date, "YMD")
    gen year = year(date)
    rename shp_cocode sa_finance1_cocode

    // keep only equity count from last reported date
    gsort company_name year
    egen max_date = max(date), by(company_name year)
    keep if date == max_date
	
	foreach var in frgn_promoters_equity  fii_equity  frgn_venture_cap_equity {
		replace `var' = "." if `var' =="NA"
	}
	destring frgn_promoters_equity  fii_equity  frgn_venture_cap_equity  total_equity, replace
    // foreign equity shares variables
    gen share_foreign_equity = (frgn_promoters_equity + fii_equity + frgn_venture_cap_equity) / total_equity
 
    gen share_frgn_equity_promoters = frgn_promoters_equity / total_equity
	gen tot_foreign_equity = (frgn_promoters_equity + fii_equity + frgn_venture_cap_equity)
	
    keep sa_finance1_cocode company_name shp_date year share_foreign_equity share_frgn_equity_promoters tot_foreign_equity total_equity
	bys sa_finance1_cocode year: keep if _n==1
    save "$output/firm_equity", replace
}
*

*** FIRM INFO: get various firm info **
    use mr_entity_type_name co_code entity_type_code owner_code owner_gp_name ///
	product_name_mst company_name nic_prod_code incorporation_year using "$source/identity", clear
    rename co_code sa_finance1_cocode
	
	// Bundle some entities 
	* Government-owned
	gen temp	=strpos(owner_gp_name, "Gov")
	gen gov_owned	= temp!=0
	gen temp2	=strpos(owner_gp_name, "State")
	replace gov_owned=1 if temp2==1 & gov_owned==0
	drop temp*
	* Foreign owned
	gen foreign = strpos(owner_gp_name, "oreign")
	gen entity			= 1 if gov_owned ==1
	replace entity 	= 2 if foreign==11 
	* private indian
	replace entity	= 3 if 	strpos(mr_entity_type_name, "Private")|strpos(mr_entity_type_name, "Liabilities")| ///
							strpos(mr_entity_type_name, "Federations")&foreign==0&gov_owned==0		
	* public indian
	replace entity	= 4 if 	strpos(mr_entity_type_name, "Public")&foreign==0&gov_owned==0		
    save "$output/firm_info", replace

	// State
	use co_code state_code using "$source/identity_2020", clear
	rename (co_code state_code) (id state)
	save "$output/state", replace
	
	
*** FINANCIALS: extract different elements of balance sheet and PnL
	// Select variables to keep 
	local profit_vars "sa_pat sa_pbdita"
	
	local totalexpense_vars "sa_rnd sa_rawmat_exp sa_salaries_bonus_pf sa_power_and_fuel_exp" 
	#delim ; 
	local totalassets_vars "sa_total_assets sa_gross_fixed_assets sa_gross_fixed_ast_cumm_dep sa_gross_fixed_ast_addn 
	sa_gross_fixed_assets sa_intangible_ast sa_goodwill sa_software sa_oth_intangible_ast sa_land_n_building sa_land sa_building sa_gross_leasehold_imprvmnts sa_plant_mach_computer_elec sa_plant sa_computer_it 
		sa_elec_install_fitting sa_transport_comm_equip_infra sa_transport_infra sa_transport_vehicles sa_comm_equip sa_furn_social_oth_fixed_ast sa_furn_and_fixtures sa_social_amenities sa_oth_fixed_ast 	
		sa_net_fixed_assets sa_net_intangible_ast sa_net_goodwill sa_net_sw sa_net_oth_intangible_ast sa_net_land_n_building sa_net_land sa_net_building sa_net_leasehold_imprvmnts sa_net_plant_mach_computer_elec sa_net_plant sa_net_computer_it  sa_mining_rights_asst
		sa_net_elec_install_fitting sa_net_transport_comm_equip_infr sa_net_transport_infra sa_net_transport_vehicles sa_net_comm_equip sa_net_furn_social_oth_fixed_ast sa_net_furn_and_fixtures sa_net_social_amenities sa_net_oth_fixed_ast " ; 
	#delim cr
	
	local totalliabilities_vars "sa_total_liabilities sa_total_capital sa_non_current_liabilities sa_curr_liab_n_prov sa_long_term_borrowings"
	local forex_vars "sa_finance1_cocode sa_finance1_year sa_forex_earnings sa_export_goods sa_export_serv"

	// Extract variables 
	use sa_finance1_cocode sa_company_name sa_finance1_year sa_months sa_total_income sa_sales sa_sale_of_goods using "$source/totalincome", replace

	merge 1:1 sa_finance1_cocode sa_finance1_year using "$source/profit", keepusing(`profit_vars') nogen keep(1 3)
	merge 1:1 sa_finance1_cocode sa_finance1_year using "$source/totalexpenses", keepusing(`totalexpense_vars') nogen keep(1 3)
	merge 1:1 sa_finance1_cocode sa_finance1_year using "$source/totalassets", keepusing(`totalassets_vars') nogen keep(1 3)
	merge 1:1 sa_finance1_cocode sa_finance1_year using "$source/totalliabilities", keepusing(`totalliabilities_vars') nogen keep(1 3)
	merge 1:1 sa_finance1_cocode sa_finance1_year using "$source/forex", keepusing(`forex_vars') nogen keep(1 3)
	
	* label variables
	lab var sa_total_income                  "Total Income"
	lab var sa_sales                         "Sales"
	lab var sa_pat "Profit"
	lab var sa_rnd "R and D"
	lab var sa_total_assets "Total Assets"
	lab var sa_total_capital "Total Capital"
	rename sa_pbdita sa_ebitda
	rename sa_pat sa_profit 
	
	destring sa_export_goods sa_export_serv sa_forex_earnings,replace force
	recode sa_export_goods . = 0
	recode sa_export_serv . = 0
	gen sa_export	= sa_export_serv+sa_export_goods

*** Bring firm info 
	merge m:1 sa_finance1_cocode using "$output/firm_info", nogen keep(3) 
	
	
************************************************
** generate NIC codes (1, 2, 4, and 5 digits) **
************************************************

*** Create nic code 
	tostring nic_prod_code, replace
	// Careful, the five digit nic code is messed up. Sometimes they only report 1 or 2 digit but the zeros might be before or after the reported number
	replace nic_prod_code = "0" + nic_prod_code+"000" if length(nic_prod_code) == 1
	drop if nic_prod_code=="34" | nic_prod_code=="89"
	replace nic_prod_code = nic_prod_code+"000" if length(nic_prod_code) == 2
	
	replace nic_prod_code = nic_prod_code+"00" if length(nic_prod_code) == 3

	gen n = nic_prod_code
	destring n,replace
	* Some are raw products (so zero should be first) others are transformed (so zero should be last)
	replace nic_prod_code = "0" + nic_prod_code if length(nic_prod_code) == 4 & (n==1111|n==1112|n==1113|n==1114|n==1118|n==1119|n==1121|n==1124|n==1132|n==1133|n==1135|n==1136|n==1139|n==1140|n==1150|n==1161|n==1162|n==1191|n==1193|n==1199)
	replace nic_prod_code = "0" + nic_prod_code if length(nic_prod_code) == 4 & (n==1210|n==1221|n==1222|n==1223|n==1239|n==1249|n==1252|n==1259|n==1261|n==1271|n==1272|n==1279|n==1282|n==1283|n==1284|n==1286|n==1291|n==1293|n==1299|n==1301)
	replace nic_prod_code = "0" + nic_prod_code if length(nic_prod_code) == 4 & (n==1411|n==1412|n==1491|n==1420|n==1462|n==1463|n==1492|n==1493|n==1499|n==1499|n==1640|n==2302|n==2303|n==2309)
	
	replace nic_prod_code = nic_prod_code + "0" if length(nic_prod_code) == 4 & (n==1030|n==1071|n==1072|n==1073|n==1075|n==1101|n==1200)
	replace nic_prod_code = nic_prod_code + "0" if length(nic_prod_code) == 4 & (n==1312|n==1393|n==1394|n==1399|n==1410|n==1430|n==1512|n==1520|n==2012|n==2021|n==2030|n==2100)
	replace nic_prod_code = nic_prod_code + "0" if length(nic_prod_code) == 4 & (n==2395|n==2410|n==2410|n==2420|n==2513|n==2610|n==2630|n==2640|n==2651|n==2710|n==2790|n==2811|n==2813|n==2825|n==2910)
	replace nic_prod_code = nic_prod_code + "0" if length(nic_prod_code) == 4 & (n==2930|n==3030|n==3240|n==3510|n==3821|n==4510|n==4530|n==4630|n==4722|n==4759|n==4761|n==4921|n==4923|n==5109|n==5210)
	replace nic_prod_code = nic_prod_code + "0" if length(nic_prod_code) == 4 & (n==5224|n==5911|n==6020|n==6130|n==6202|n==6920|n==7100|n==7210|n==7292|n==7293|n==7294|n==7295|n==7299|n==8101|n==8102|n==8104|n==8105|n==8106|n==8107|n==8108|n==8109|n==8911|n==8912|n==8915|n==8919|n==8931|n==8994|n==8996|n==8998|n==8999)

	gen nic2008_4digit = substr(nic_prod_code, 1, 4)
	gen nic2008_5digit = substr(nic_prod_code, 1, 5)
	
	
** NIC Division level code - 2-digits
	gen nic_division = substr(nic_prod_code, 1, 2)
	lab var nic_division "2-digit NIC Division (2008)"

** NIC section level code - 1-digit
	gen nic_section = "."
	replace nic_section = "A-Agriculture, forestry, and fishing" if inlist(nic_division, "01", "02", "03")
	replace nic_section = "B-Mining and quarrying" if inlist(nic_division, "05", "06", "07", "08", "09")

	replace nic_section = "C-Manufacturing" if inlist(nic_division, "10", "11", "12", "13", "14", "15", "16", "17", "18")
	replace nic_section = "C-Manufacturing" if inlist(nic_division, "19", "20", "21", "22", "23", "24", "25", "26", "27")
	replace nic_section = "C-Manufacturing" if inlist(nic_division, "28", "29", "30", "31", "32", "33")

	replace nic_section = "D-Electricity, gas, steam, aircondition supply" if inlist(nic_division, "35")
	replace nic_section = "E-Water supply; sewerage and waste management" if inlist(nic_division, "36", "37", "38", "39")
	replace nic_section = "F-Construction" if inlist(nic_division, "41", "42", "43")
	replace nic_section = "G-Wholesale and retail trade; repair of motor vehicles and motorcycles" if inlist(nic_division, "45", "46", "47")
	replace nic_section = "H-Transport and storage" if inlist(nic_division, "49", "50", "51", "52", "53")
	replace nic_section = "I-Accomodation and food service activities" if inlist(nic_division, "55", "56")
	replace nic_section = "J-Information and communication" if inlist(nic_division, "58", "59", "60", "61", "62", "63")
	replace nic_section = "K-Financial and insurance activities" if inlist(nic_division, "64", "65", "66")
	replace nic_section = "L-Real estate activities" if inlist(nic_division, "68")
	replace nic_section = "M-Professional, scientific, and technical activities" if inlist(nic_division, "69", "70", "71", "72", "73", "74", "75")
	replace nic_section = "N-Administrative and support service activities" if inlist(nic_division, "77", "78", "79", "80", "81", "82")
	replace nic_section = "O-Public administration and defence; compulsory social security" if inlist(nic_division, "84")
	replace nic_section = "P-Education" if inlist(nic_division, "85")
	replace nic_section = "Q-Human health and social work activities" if inlist(nic_division, "86", "87", "88")
	replace nic_section = "R-Arts, entairtainment and recreation" if inlist(nic_division, "90", "91", "92", "93")
	replace nic_section = "S-Other service activities" if inlist(nic_division, "94", "95", "96")
	replace nic_section = "T-Activities of households as employers; undifferentiated goods- and services producing activities of households for own use" if inlist(nic_division, "97", "98")
	replace nic_section = "U-Activities of extraterritorial organizations and bodies" if inlist(nic_division, "99")
	replace nic_section = "Diversified" if inlist(nic_division, "34")

	lab var nic_section "NIC Sections (2008)"
	
*** Additional NIC level 
	gen nic_2digit = substr(nic_prod_code, 1, 2)
	gen nic_3digit = substr(nic_prod_code, 1, 3)
	gen nic_4digit = substr(nic_prod_code, 1, 4)

	lab var nic_2digit "NIC 2-digit 2008"
	lab var nic_3digit "NIC 3-digit 2008"
	lab var nic_4digit "NIC 4-digit 2008"

*** Basic cleaning 
	drop if missing(sa_finance1_cocode) | missing(sa_finance1_year)

	keep if nic_section == "C-Manufacturing"

*** Date variables 
	tostring sa_finance1_year, replace
	gen date_report = date(sa_finance1_year, "YMD")
	gen year_report = year(date_report)
	gen month_report = month(date_report)
	format date_report %td
	
*** Firm age
	egen minyr = min(year),by(sa_finance1_cocode)
	gen firm_age = year - incorporation_year  

	// for cases where they were incorporated after the first year they appeared in the data
	replace firm_age = year - minyr if firm_age <0  | incorporation_year == . 
	replace firm_age = firm_age + 1 if firm_age == 0  // deal with age zero firms

	lab var firm_age "age of firm in years"
	drop minyr
	gen firm_age_2 = firm_age^2
	lab var firm_age_2 "firm age squared"
	
*** Rename some var 
	rename sa_total_capital equity 
	* recode long-term liability as tot liability - ST - equity
	rename sa_curr_liab_n_prov st_liability
	rename sa_total_liabilities tot_liability

* recode weird equity value 
replace equity = 0 if equity<0

* when lt liabilities is not missing, make sure that total liability = equity + debt
replace tot_liability = st_liability +sa_non_current_liabilities + equity if st_liability<. & sa_non_current_liabilities<. & equity<.

* make sure that equity+ st liability is never bigger than total liability 
replace tot_liability = st_liability + equity if (st_liability + equity)>tot_liability & st_liability<. & equity<.

* make sure that equity cannot be bigger than tot liability 
replace tot_liability = equity if (equity)>tot_liability &  equity<.

gen lt_liability = tot_liability- equity - st_liability


*** Create PPEG 
recode sa_intangible_ast . = 0 
gen ppeg1 = sa_gross_fixed_assets - sa_intangible_ast

foreach var in software  mining_rights_asst  land_n_building plant_mach_computer_elec transport_comm_equip_infra{
	recode sa_`var' . = 0
	rename sa_`var' `var'
}
gen ppeg2	= software + mining_rights_asst + land_n_building + plant_mach_computer_elec + transport_comm_equip_infra
gen ppeg3	=  land_n_building + plant_mach_computer_elec 

*** SAVE 
save "$output/firms_financials", replace

