

#delimit ;

local firm_info_vars "nic* sa_finance1_cocode
                      sa_finance1_year
                      sa_months
                      incorporation_year
					  firm_age gov_owned
					  entity foreign";

local flow_financial_vars "sa_total_income
                           sa_sales
						   sa_sale_of_goods
                           sa_ebitda sa_profit
                           sa_salaries_bonus_pf
                           sa_rawmat_exp
                           sa_power_and_fuel_exp
                           sa_rnd
                           sa_gross_fixed_ast_addn
						   sa_forex_earnings sa_export
                           ";

local stock_financial_vars "tot_liability st_liability lt_liability equity
                            sa_total_assets
                            sa_gross_fixed_assets
                            sa_gross_fixed_ast_cumm_dep
							ppeg1 ppeg2 ppeg3 
							sa_gross_fixed_ast_cumm_dep sa_gross_fixed_ast_addn sa_gross_fixed_assets sa_intangible_ast";

#delimit cr

use "$output/firms_financials", clear

************************
** data restrictions ***
************************

keep `flow_financial_vars' `stock_financial_vars' `firm_info_vars'

*******************************************
** Fix reporting date for flow variables **
preserve

// Create new rows to prorate flow data
sort sa_finance1_cocode sa_finance1_year
tostring sa_finance1_year, replace
gen date_report = date(sa_finance1_year, "YMD")
gen year_report = year(date_report)
gen month_report = month(date_report)

gen sa_sales_ori = sa_sales

// gen year_adj = year_report + 1

format date_report %td

/* EXPAND OBSERVATIONS that correspond to more than one financial year
verified that the cases below are exhaustive */

// reporting IN march

// leq 12 months of data => no splitting
gen expand_n = 1 if month_report == 3 & sa_months <= 12
// more than 12 months of data => split between financial years
replace expand_n = ceil(sa_months / 12) if month_report == 3 & sa_months > 12

// reporting AFTER march

// data is for the gap since march or within the gap
replace expand_n = 1 if month_report > 3 & sa_months <= month_report - 3
// data overlaps previous financial year(s)
replace expand_n = ceil((sa_months - month_report + 3)/ 12) + 1 if month_report > 3 & sa_months > month_report - 3

// reporting BEFORE march

// data contained within the same financial year
replace expand_n = 1 if month_report < 3 & sa_months <= 9 + month_report
// data overlaps previous financial year(s)
replace expand_n = ceil((sa_months - 9 - month_report)/ 12) + 1 if month_report < 3 & sa_months > 9 + month_report

expand expand_n

// YEAR_ADJ = financial year (!= calendar year) that data corresponds to
sort sa_finance1_cocode date_report expand_n
gen year_adj = .

// reporting IN march
by sa_finance1_cocode date_report expand_n: replace year_adj = year_report if month_report == 3 & expand_n == 1
by sa_finance1_cocode date_report expand_n: replace year_adj = year_report - _n + 1 if month_report == 3 & expand_n > 1

// reporting AFTER march
by sa_finance1_cocode date_report expand_n: replace year_adj = year_report + 1 if month_report > 3 & expand_n == 1
by sa_finance1_cocode date_report expand_n: replace year_adj = year_report - _n + 2 if month_report > 3 & expand_n > 1

// reporting BEFORE march
by sa_finance1_cocode date_report expand_n: replace year_adj = year_report if month_report < 3 & expand_n == 1
by sa_finance1_cocode date_report expand_n: replace year_adj = year_report -_n + 1 if month_report < 3 & expand_n > 1


// DATE_ADJ = adjusted date for the reporting
gen date_adj = mdy(3, 31, year_adj)


/* MONTHS_ADJ = number of months that correpond to the adjusted year */
sort sa_finance1_cocode date_report expand_n

// no splitting => data needs no adjustment
gen months_adj = sa_months if expand_n == 1

// reporting IN march AND data splitting
// data corresponding to the financial year reported in
by sa_finance1_cocode date_report expand_n: replace months_adj = 12 if month_report == 3 & sa_months > 12 & _n == 1
// previous financial years
by sa_finance1_cocode date_report expand_n: replace months_adj = min(sa_months - 12 * (year_report - year_adj), 12) if month_report == 3 & sa_months > 12 & _n != 1

// reporting AFTER march AND data splitting
// corresponding to the financial year reported in
by sa_finance1_cocode date_report expand_n: replace months_adj = month_report - 3 if month_report > 3 & sa_months > month_report - 3 & _n == 1
// previous financial years
by sa_finance1_cocode date_report expand_n: replace months_adj = min(sa_months - (month_report - 3) - 12 * (year_adj[1] - year_adj - 1), 12) if month_report > 3 & sa_months > month_report - 3 & _n != 1

// reporting BEFORE march AND data splitting
// corresponding to the financial year reported in
by sa_finance1_cocode date_report expand_n: replace months_adj =  9 + month_report if month_report < 3 & sa_months > 9 + month_report & _n == 1
// previous financial years
by sa_finance1_cocode date_report expand_n: replace months_adj =  min(sa_months - (9 + month_report) - 12 * (year_adj[1] - year_adj - 1), 12) if month_report < 3 & sa_months > 9 + month_report & _n != 1

/* At this point, months_adj is <= 12. Now I am simply going to sort these by + firm + year + expand_n - months and then keep the _n == 1 observation.
   Sorting by expand_n to give priority to observations where no splitting was required.
   Next step will be to scale or not to scale the observations with < 12 months. */

egen missings = rowmiss(_all)  

gsort + sa_finance1_cocode + year_adj + expand_n - months_adj + missings + sa_finance1_year
by sa_finance1_cocode year_adj: keep if _n == 1

isid sa_finance1_cocode year_adj

foreach flow_var of local flow_financial_vars {
  replace `flow_var' = `flow_var' * months_adj / sa_months
}


// keep only relevant variables
* keep sa_finance1_cocode year_adj `flow_financial_vars'
local vars_to_keep: list flow_financial_vars | firm_info_vars
keep `vars_to_keep' year_adj months_adj sa_sales_ori

save "$output/financial_flow_adjusted", replace

restore


**********************************
** Fix reporting date for stock **
**********************************

preserve

sort sa_finance1_cocode sa_finance1_year

tostring sa_finance1_year, replace
gen date_report = date(sa_finance1_year, "YMD")
gen year_report = year(date_report)
gen month_report = month(date_report)

* bring equity composition 
gen year =year_report 
merge m:1 sa_finance1_cocode year using "$output/firm_equity", nogen keep(1 3) 


// keep only relevant vars
local temp_vars "sa_finance1_cocode date_report year_report month_report"
local vars_to_keep: list stock_financial_vars | temp_vars
keep `vars_to_keep' total_equity tot_foreign_equity

gen year_adj = year_report if month_report <= 3
replace year_adj = year_report + 1 if month_report > 3

sort sa_finance1_cocode year_adj

gen sorter = .

by sa_finance1_cocode year_adj: replace sorter = 1 if month_report == 3
by sa_finance1_cocode year_adj: replace sorter = 2 if month_report == 2
by sa_finance1_cocode year_adj: replace sorter = 3 if month_report == 1
by sa_finance1_cocode year_adj: replace sorter = 4 if month_report == 12
by sa_finance1_cocode year_adj: replace sorter = 5 if month_report == 11
by sa_finance1_cocode year_adj: replace sorter = 6 if month_report == 10
by sa_finance1_cocode year_adj: replace sorter = 7 if month_report == 9
by sa_finance1_cocode year_adj: replace sorter = 8 if month_report == 8
by sa_finance1_cocode year_adj: replace sorter = 9 if month_report == 7
by sa_finance1_cocode year_adj: replace sorter = 10 if month_report == 6
by sa_finance1_cocode year_adj: replace sorter = 11 if month_report == 5
by sa_finance1_cocode year_adj: replace sorter = 12 if month_report == 4

sort sa_finance1_cocode year_adj sorter

by sa_finance1_cocode year_adj: keep if _n == 1  

isid sa_finance1_cocode year_adj

keep sa_finance1_cocode year_adj `stock_financial_vars' total_equity tot_foreign_equity
save "$output/financial_stock_adjusted", replace

restore


**************************************************************
** Adjust financial information according to reporting date **
**************************************************************

use "$output/financial_flow_adjusted", replace

  foreach fvar of local flow_financial_vars {

    // final scaling of flow variables
    replace `fvar' = `fvar' * 12 / months_adj if months_adj < 12

    // Rename scaled variables by appending _year suffix
    // to ensure that code down the pipeline will work
    rename `fvar' `fvar'_year
    notes `fvar'_year:  scaled flow variables /  prepare.do

  }

  lab var year_adj "Adjusted year variable to account for differential reporting dates"

// merge in stock variables in 3a_stock
merge 1:1 sa_finance1_cocode year_adj using "$output/financial_stock_adjusted", nogen 

rename year_adj year

	// FDI policy reform data 
	merge m:1 nic2008_5digit using "$source/fdi_restrictions_5digitNIC", nogen keep(1 3)

*** Replace gross fixed asset with gross fixed assets net of cummulative depreciation
	replace sa_gross_fixed_assets = sa_gross_fixed_assets - sa_gross_fixed_ast_cumm_dep
	lab var sa_gross_fixed_assets "Gross fixed asset minus cumulative depreciation"

**************
** clean up **
**************

gsort sa_finance1_cocode year

// drop duplicates at the firm-year level !!!
bysort sa_finance1_cocode year: gen dup = (_n==1)
drop if dup != 1
drop dup

drop if missing(sa_finance1_cocode) | missing(year)


*** Compute growth rate
sort sa_finance1_cocode year
by sa_finance1_cocode: gen gsale = log(sa_sales_year/ sa_sales_year[_n-1])
winsor gsale 1 
egen group = group(sa_finance1_cocode)

*** Compute beta 
su group, meanonly
forval ind = 2/4{
gen beta_gsale_ind`ind'1 = . 
gen beta_gsale_ind`ind'2 = . 

egen mgsale`ind'1 			= mean(gsale) , by(nic_`ind'digit year)
egen totmgsale`ind'1 		= sum(mgsale`ind'1),by(year nic_`ind'digit)
replace totmgsale`ind'1 	= totmgsale`ind'1  - gsale
egen totobs`ind'			= sum(1) ,by(year nic_`ind'digit)
gen mgsale`ind'2 			= totmgsale`ind'1 /(totobs`ind'-1)

}
forval ind = 2/4{
display in red "`ind'" 
su group, meanonly
forval i =1/`r(max)'{
display `i'

capture reg gsale mgsale`ind'1 if year<=2000 & group ==`i'
capture gen temp1	= _b[mgsale`ind'1]  if group ==`i'
capture replace beta_gsale_ind`ind'1	= temp1 if group ==`i'
capture reg gsale mgsale`ind'2 if year<=2000 & group ==`i'
capture gen temp2	= _b[mgsale`ind'2]  if group ==`i'
capture replace beta_gsale_ind`ind'2	= temp2 if group ==`i'
capture drop temp*
}
}

gen beta_gsale_all1 = . 
gen beta_gsale_all2 = . 

egen mgsale_all1		= mean(gsale),by(year)
egen totmgsale_all		= sum(mgsale_all1),by(year)
replace totmgsale_all 	= totmgsale_all - gsale
egen totobs				= sum(1) ,by(year)
gen mgsale_all2 		= totmgsale_all/(totobs-1)

su group, meanonly
forval i =1/`r(max)'{
capture reg gsale mgsale_all1 if year<=2000 & group ==`i'
capture gen temp1	= _b[mgsale_all1]  if group ==`i'
capture replace beta_gsale_all1	= temp1 if group ==`i'
capture reg gsale mgsale_all2 if year<=2000 & group ==`i'
capture gen temp2	= _b[mgsale_all2]  if group ==`i'
capture replace beta_gsale_all2	= temp2 if group ==`i'
capture drop temp*
}


// save data
save "$output/firms_financials_adjusted", replace





