



*** Prepare NIC Crosswalk to convert 2008 nic codes to 1987
    * 2008 to 2004 NIC concordance
	use "$source/nic_crosswalk/NIC0408Crosswalk_4digit", clear
    rename (nic408 nic04_4) (nic08_4digit nic04_4digit)
    save "$output/nic08to04", replace

    * 2004 to 1987 NIC concordance
	use "$source/nic_crosswalk/nic_04_87_4d_composite", clear
    rename (nic04_4 nic387) (nic04_4digit nic87_3digit)
    save "$output/nic04to87", replace

	
*** ASSEMBLE DEFLATORS	
	// Yearly deflators
	* Capital deflator	
    insheet using "$source/deflators/RBI Capital Formation Accounts.csv", comma names clear
    keep year capital_deflator
    replace year = substr(year,1,4)
    destring year, replace
    replace year = year + 1     // To match 2018 calendar year with March 31 year end in Prowess
    tempfile capdefl
    save `capdefl'
	
	* Electricity deflator
    insheet using "$source/deflators/electricity deflator_RBI.csv", comma names clear
    keep year electricity_deflator
    g base=electricity_deflator if year=="2004-05"
    egen basedefl=sum(base)
    replace electricity_deflator=electricity_deflator/basedefl*100
    drop base*
    replace year = substr(year,1,4)
    destring year, replace
    replace year = year + 1 // To match 2018 calendar year with March 31 year end in Prowess
    tempfile elecdefl
    save `elecdefl'
	
	* National deflator
    insheet using "$source/deflators/gdp deflator national.csv", comma clear names
    replace year = year + 1 // To match 2018 calendar year with March 31 year end in Prowess
	merge 1:1 year using `capdefl', nogen 
	merge m:1 year using `elecdefl', nogen 
	save "$output/yearly_deflator", replace
	
	// Input - Output deflator (vary by industry-year: 3-digit 1987 codes
    use "$source/deflators/final input deflator", clear
    rename nic3digit nic87_3digit
    replace year = year + 1     // To match 2018 calendar year with March 31 year end in Prowess
    save "$output/input_deflator", replace

    use "$source/deflators/final output deflator", clear
    rename nic3digit nic87_3digit
    rename deflator output_deflator
	replace year = year + 1 // To match 2018 calendar year with March 31 year end in Prowess
	
	merge 1:1 nic87_3digit year using "$output/input_deflator",nogen 
    save "$output/input_output_deflator", replace

	
*** MERGE WITH PROWESS
	use "$output/firms_financials_adjusted", clear
	
	* Apply NIC Crosswalk to convert 2008 nic codes to 1987
	rename nic_4digit nic08_4digit
	merge m:1 nic08_4digit using "$output/nic08to04", nogen keep(1 3)
	merge m:1 nic04_4digit using "$output/nic04to87", nogen keep(1 3)
	* Bring deflators 
	merge m:1 nic87_3digit year using "$output/input_output_deflator", nogen keep(1 3) 
	merge m:1 year using "$output/yearly_deflator", nogen keep(1 3) 
	
	
*** Deflate values
	* Output
	gen sa_sales_year_defl= sa_sales_year / ( output_deflator / 100 )

	* Inputs
	gen sa_rawmat_exp_year_defl= sa_rawmat_exp_year / ( input_deflator / 100 )
	
	* Wages
	gen sa_salaries_bonus_pf_year_defl= sa_salaries_bonus_pf_year / ( gdp_defl_natl / 100 )

	* Electricity
	gen sa_power_and_fuel_exp_year_defl= sa_power_and_fuel_exp_year / ( electricity_deflator / 100 )
	
	* Capital 
	gen sa_gross_fixed_assets_defl = sa_gross_fixed_assets / ( capital_deflator  )

	* Export 
	gen sa_export_year_defl= sa_export_year / ( output_deflator / 100 )
	gen sa_foreignrev_year_defl= sa_forex_earnings_year / ( output_deflator / 100 )
	
	
*** Clean up: drop negatives (drops about 100 observations)
	drop if sa_sales_year_defl < 0 | ///
	sa_rawmat_exp_year_defl < 0 | ///
	sa_salaries_bonus_pf_year_defl < 0 | ///
	sa_power_and_fuel_exp_year_defl < 0 | ///
	sa_gross_fixed_assets_defl < 0
	
*** Construct simple measures of MPK, MPL and MPM	
	* MPK = Y/K
	gen mpk_YK = sa_sales_year_defl / sa_gross_fixed_assets_defl
	lab var mpk_YK "MPK = deflated sales over deflated gross fixed assets"

	* MPL = Y/L
	gen mpl_YL =sa_sales_year_defl / sa_salaries_bonus_pf_year_defl
	lab var mpl_YL "MPL = delflated sales / deflated salaries"

	* MPM = Y/M
	gen mpm_YM =sa_sales_year_defl / sa_rawmat_exp_year_defl
	

*** bundle some sic2 for LP estimation 
	destring nic2008_4digit, replace
	gen nic2_adj = floor(nic2008_4digit/100)
	replace nic2_adj = 11 if nic2_adj==12 | nic2_adj==10
	replace nic2_adj = 18 if nic2_adj==19	
	replace nic2_adj = 25 if nic2_adj==26
	replace nic2_adj = 30 if nic2_adj==31|nic2_adj==32	
	
*** Save	
save "$output/firms_financials_adjusted_MPK_YK", replace
	
	
