


*** call the modified version of LP 
	do "$do/levpet/levpet_dw.do"
	do "$do/levpet/levept_p_dw.do"
	do "$do/levpet/lp_bs_ss_dw.do"
	do "$do/levpet/lp_gmm_dw.do"
	do "$do/levpet/lp_gmm_grid_dw.do"
	do "$do/levpet/lp_srch_dw.do"
	do "$do/levpet/nllp_bs_gmm_dw.do"
	
*** Decide at which nic class we want to estimate the parameters
	local nic_class "nic2_adj"
	
*** extract the right variables firm financial 
global tfpvar "`nic_class' sa_sales_year_defl sa_salaries_bonus_pf_year_defl sa_rawmat_exp_year_defl sa_gross_fixed_assets_defl sa_finance1_cocode year sa_power_and_fuel_exp_year_defl"
	use $tfpvar using "$output/firms_financials_adjusted_MPK_YK", clear
	
	// rename 
	gen id = sa_finance1_cocode  
	rename sa_salaries_bonus_pf_year_defl L
	rename sa_rawmat_exp_year_defl M 
	rename sa_gross_fixed_assets_defl K 
	rename sa_power_and_fuel_exp_year_defl E
	rename sa_sales_year_defl S
	
	foreach var in L K M S {
	gen l = log(`var')
	replace `var' = l 
	drop l 
	}
	foreach var in labour capital rawmat{
	gen `var'_coef_lp_rm = . 
	}
	save "$output/temp", replace 
	
	local bootstrap_reps = 2  
	
    levelsof `nic_class', local(nic_class_list)
			
	foreach nc of local nic_class_list {	
	preserve
	local bootstrap_reps = 2  
	keep if `nic_class'==`nc' 
    display in red "NIC 2-Digit: `nc' from `nic_class'"
	local free_var "L"
	local proxy_var_mat "M"
	local proxy_var_pow "E"
	local cap_stock "K"
	
	// Classic LP 
    quietly : levpet_dw S , ///
    free(`free_var') proxy(`proxy_var_mat') capital(`cap_stock') revenue reps(`bootstrap_reps') i(id) t(year) 

   * save coefficients to var
   quiet cap replace labour_coef_lp_rm 	= _b[`free_var'] if `nic_class'==`nc'
   quiet cap replace capital_coef_lp_rm = _b[`cap_stock'] if `nic_class'==`nc'
   quiet cap replace rawmat_coef_lp 	= _b[`proxy_var_mat'] if `nic_class'==`nc'
  	keep *coef* `nic_class'
    * save estimates of parameters to table **
    save "$output/tfp_coeff_nic2_`nc'", replace
	restore  
}	

*** NOW ASSEMBLE EVERYTHING
	use nic2_adj using "$output/temp", replace 
    levelsof nic2_adj, local(nic_class_list_coeff)
	clear
	save "$output/lp_coeff", replace emptyok // blank table that will eventually become a panel with all the variables
	foreach nc of local nic_class_list_coeff {
	append using "$output/tfp_coeff_nic2_`nc'"
	}
	bys nic2_adj: keep if _n==1
	save "$output/lp_coeff", replace

	
*** Estimate TFPR
	use "$output/temp", replace 

	* LP 
	merge m:1 nic2_adj using "$output/lp_coeff",nogen
		
	* TFPR
	gen tfp_lp_rm	= S - (labour_coef_lp_rm*L) - (rawmat_coef_lp*M) - (capital_coef_lp_rm*K)

*** Calculate MPK (derivative of production function wrt to K);
#delimit ;

gen mpk_lp = capital_coef_lp_rm *
                tfp_lp_rm *
                (L ^ labour_coef_lp_rm) *
                (M ^ rawmat_coef_lp) *
                (K ^
                (capital_coef_lp_rm - 1));
lab var mpk_lp "MPK from TFP using LevPet";


*** calculate MPL (derivative of production function wrt to K);
gen mpl_lp = labour_coef_lp_rm *
                tfp_lp_rm *
                (L ^ (labour_coef_lp_rm - 1) ) *
                (M ^ rawmat_coef_lp) *
                (K ^ capital_coef_lp_rm);
lab var mpl_lp "MPL from TFP using LevPet";

*** calculate MPM (derivative of production function wrt to M);
gen mpm_lp = rawmat_coef_lp * 
                tfp_lp_rm * 	
                (L ^ labour_coef_lp_rm ) * 
                (M ^ (rawmat_coef_lp - 1) ) * 	
                (K ^ capital_coef_lp_rm) ; 
lab var mpm_lp "MPM from TFP using LevPet";
#delimit cr

*** Keep LP coeff and merge back to main sample 
keep *_lp* sa_finance1_cocode year

*** Save results
	save "$output/firms_financials_adjusted_MPK_LP", replace

