


{
use "$output/firms_financials_adjusted_MPK_YK", clear

merge 1:1 sa_finance1_cocode year using "$output/firms_financials_adjusted_MPK_LP", nogen keep(1 3) 

rename sa_finance1_cocode id 
keep if year>=1995 & year<=2015

local year_before_first_FDI_reform 2001  // set pre-FDI reform dummy year
local year_after 1995  // exclude years before 1995 because it is messy

// Parameters to set
local years_before_after "`year_after'`year_before_first_FDI_reform'"
local i 2  // percentile of mpk (2 == median)
local industry nic2008_4digit  // industry level within which to calculate median


*** Define program to create marginal product median variables 
{
* calculate firm mean marginal product before first year of reform (excluding years before year_after)
capture program drop firm_mean_mp
program define firm_mean_mp
    args mp yr year_after year_before_first_FDI_reform i

    bysort id: egen mean_firm_`mp'_pre_`year_before_first_FDI_reform' = mean(`mp') if ///
    `yr' > `year_after' & ///
    `yr' <= `year_before_first_FDI_reform' & ///
    !missing(`mp')

    bysort id: egen MAX_mfirm_`mp'pre_`year_before_first_FDI_reform' = max(mean_firm_`mp'_pre_`year_before_first_FDI_reform')
end

* calculate median marginal product before first year of reform WITHIN industries
capture program drop within_industry_median
program define within_industry_median
    args mp yr year_after year_before_first_FDI_reform i industry

    * median
    bysort `industry': egen `mp'_indmedianpre_`year_before_first_FDI_reform' = median(`mp') if ///
    `yr' > `year_after' & ///
    `yr' <= `year_before_first_FDI_reform' & ///
    !missing(`mp')

    bysort `industry': egen MAX_`mp'_indmedianpre_`year_before_first_FDI_reform' = max(`mp'_indmedianpre_`year_before_first_FDI_reform')

    * indicator
    gen `mp'_high`i'_withinind_`year_before_first_FDI_reform' = .
    lab var `mp'_high`i'_withinind_`year_before_first_FDI_reform' "Within-industry indicator for mean `mp' > median `mp' indicator before first FDI reform"
    bysort id: replace `mp'_high`i'_withinind_`year_before_first_FDI_reform' = 1 if ///
        MAX_mfirm_`mp'pre_`year_before_first_FDI_reform'  > MAX_`mp'_indmedianpre_`year_before_first_FDI_reform' & ///
        !missing(MAX_mfirm_`mp'pre_`year_before_first_FDI_reform' ) & !missing(MAX_`mp'_indmedianpre_`year_before_first_FDI_reform')
    bysort id: replace `mp'_high`i'_withinind_`year_before_first_FDI_reform' = 0 if ///
        MAX_mfirm_`mp'pre_`year_before_first_FDI_reform'  <MAX_`mp'_indmedianpre_`year_before_first_FDI_reform' & ///
        !missing(MAX_mfirm_`mp'pre_`year_before_first_FDI_reform' ) & !missing(MAX_`mp'_indmedianpre_`year_before_first_FDI_reform')
end
}
*
*** Calculate above median mpk indicators
	// MPK = Y/K	
	foreach yr in 1996 1997 1998 1999 2001{
	local year_before_first_FDI_reform `yr'
	firm_mean_mp mpk_YK year `year_after' `year_before_first_FDI_reform' `i'
	within_industry_median mpk_YK year `year_after' `year_before_first_FDI_reform' `i' `industry'	
	}
	local year_before_first_FDI_reform 2001
	// MPL = Y/L
	firm_mean_mp mpl_YL year `year_after' `year_before_first_FDI_reform' `i'
	within_industry_median mpl_YL year `year_after' `year_before_first_FDI_reform' `i' `industry'

	// MPM = Y/M
	firm_mean_mp mpm_YM year `year_after' `year_before_first_FDI_reform' `i'
	within_industry_median mpm_YM year `year_after' `year_before_first_FDI_reform' `i' `industry'

	// MPK = LP 
	firm_mean_mp mpk_lp year `year_after' `year_before_first_FDI_reform' `i'
	within_industry_median mpk_lp year `year_after' `year_before_first_FDI_reform' `i' `industry'

	// MPL = LP 
	firm_mean_mp mpl_lp year `year_after' `year_before_first_FDI_reform' `i'
	within_industry_median mpl_lp year `year_after' `year_before_first_FDI_reform' `i' `industry'

	// MPM LP 
	firm_mean_mp mpm_lp year `year_after' `year_before_first_FDI_reform' `i'
	within_industry_median mpm_lp year `year_after' `year_before_first_FDI_reform' `i' `industry'

*** Merge additional information
	// IO Table 
	merge m:1 nic_division year using "$source/io_table" ,nogen keep(1 3) 
	
	// Capital ventilation 
	merge 1:1 id year using "$output/capital_ventilation",nogen keep(1 3)

*** Sample selection	
	*only 67 relevant observations
	drop if fdi_year_of_reform ==1998
	
	* Remove firms for which high / low MPK dummy is not defined 
	gen mpk_YK_high2_withinind = mpk_YK_high2_withinind_2001
	keep if mpk_YK_high2_withinind<. 
	  
*** Create additional variables	  
	gen treated = fdi_year_of_reform<year
	
	// Name some shortcut variables 
	gen L =  sa_salaries_bonus_pf_year_defl 
	gen M =  sa_rawmat_exp_year_defl 
	gen K =  sa_gross_fixed_assets_defl 
	gen E =  sa_power_and_fuel_exp_year_defl 
	
	// fill missing with average weight in nic3-state
	* bring state
	merge m:1 id using "$output/state",nogen keep(3)
	gen nic3 = floor(nic2008_4digit/10)	
	
	foreach var in L M K E{
	gen s_`var' = `var'/sa_sales_year_defl
	winsor s_`var' 1
	egen ms_`var' 	= mean(s_`var'),by(nic3 state)
	replace `var'	= sa_sales_year_defl*ms_`var' if `var'  == .
	}

	replace sa_salaries_bonus_pf_year_defl = L
	replace sa_rawmat_exp_year_defl = M
	replace sa_gross_fixed_assets_defl = K
	replace sa_power_and_fuel_exp_year_defl= E
	drop K M L
		
*** Take logs
	rename sa_salaries_bonus_pf_year_defl wage_level
	foreach var in sa_export_year_defl sa_sales_year_defl sa_gross_fixed_assets_defl wage_level sa_rawmat_exp_year_defl mpk_YK ///
	lt_liability st_liability tot_liability equity /// 
	mpk_lp mpl_YL mpl_lp mpm_lp { 
	gen log_`var'=log(`var')
	}		

*** Rename some variables 	
	rename log_sa_sales_year_defl 				sale  
	rename log_sa_gross_fixed_assets_defl 		K 
	rename log_wage_level 						wage
	rename log_sa_rawmat_exp_year_defl			M
	rename log_sa_export_year_defl 				export
		
	* keep level of MPK with LP for Solow aggregation
	foreach var in mpk_lp mpl_lp mpm_lp{
	gen `var'_Lev = `var'
	}
	
	capture drop mpk_YK mpk_lp mpl_YL mpl_lp mpm_lp  // 
	foreach var in mpk_YK mpk_lp mpl_YL mpl_lp mpm_lp{ // 
	rename log_`var' `var'
 	}

*** Create fixed effects
	* State
	egen stateyr	= group(state year)
	* Industries
	egen nic5yr 	= group(nic2008_5digit year)
	
	* Size pre-reform 
	capture drop sizepre msize* sizeq*
		gen sizepre		= sa_gross_fixed_assets_defl if year<=2000
		egen msize		= mean(sizepre),by(id)
		* split in quartile within Nic-2digit to account for the fact that some industries are structurally bigger than others
		foreach x in 4 {
		egen msizeq`x' 		= xtile(msize),nq(`x') by(nic_2digit)
		egen sizeq`x'yr 	= group(msizeq`x' year)
		}	

*** Share foreign export in sales 
	gen s_export	= sa_export_year_defl / sa_sales_year_defl 
	winsor s_export 1 // a few weird outliers are bigger than 1 
	
*** Label for regressions 	
	gen high_treated =.
	label var high_treated "\it{Reform}\tsub{\it{jt}} $\times I\tsub{\it{i}}^{\text{\it{High\:MRPK}}}$"
	label var treated " $\mathit{Reform}\tsub{\it{jt}}$ "
		
save "$output/final_data_notfpq", replace
}
*

***************************************************************
**********	PREPARE FINAL SAMPLE	***************************
***************************************************************
{
*** Bring TFPQ estimation 
	do "$do/revenue_production_functions.do"
	
	use "$output/final_data_notfpq", replace		
	merge 1:1 id year using "$output/tfpr_tfpq",nogen 
	capture drop _m 
	save "$output/final_data_02", replace

*** Apply final filters: some firms almost disappear from the sample and have absurb yearly growth rate in their final year which creates massive outliers 
	use "$output/final_data_02", replace
	* Compute sales growth to identify outliers 
	sort id year 
	by id: gen G = sale-sale[_n-1] if year==year[_n-1] +1
	by id: gen Graw = (sa_sales_year-sa_sales_year[_n-1])/ sa_sales_year[_n-1] if year==year[_n-1] +1
	
	gen G_pre	= G if year<=2001

	gen TEMP	= G_pre<-1.2  if G_pre<.
	egen jump	= max(TEMP),by(id) // 8% of obs 
	drop if jump ==1
	capture drop _m
	save "$output/final_data_03", replace	

*** Product sample
use "$output/product_clean",clear
	* bring portfolio product data
	merge m:1 id year using  "$output/product_portfolio",nogen keep(3)
	gen log_nbprod		= log(nbprod2)
	gen addition		= addition2>0 if addition2<.
	gen deletion		= deletion2>0 if deletion2<.

	* bring firm level controls
	merge m:1 id year using  "$output/final_data_notfpq_03",nogen keep(3) force
	
	* identify firms where products sales really do not match aggregate sales 
	gen defl 		= sa_sales_year/sa_sales_year_defl  		// deflator 
	gen sv 			= sales_value*defl	
	egen sales_firm = total(sv), by(id year)
	gen s_sale 		= sales_firm/sa_sales_year_defl
	* drop really big deviations from aggregate sales
	keep if s_sale>0.3&s_sale<1.2	

	capture drop _m
save "$output/product_final_03",replace

}
*


























