



**********************************************************************
**********	COMPUTE INDUSTRY LEVEL IN PROWESS	**********************
**********************************************************************
{
use  "$source/__dereservation", clear
	* Identify asicc that deregulates post 2001 and post 2006
	destring YEAR,replace
	destring asicc, replace
	foreach yr in 2001 2005 2006{
	gen temp`yr'	= YEAR>=`yr'
	egen dereg`yr' = max(temp`yr'),by(asicc)
	}
	egen myear		= mean(YEAR),by(asicc)
	egen maxyear	= max(YEAR),by(asicc)	
	replace myear	= round(myear)	
	bys asicc: keep if _n==1 // some asicc appears 10 times
	* merge with nic 2008 to identify the nic affected
	merge 1:m asicc using "$source/nic08_asicc_asi_max",nogen keep(3)
	keep nic2008_5digit dereg* myear maxyear
	*destring nic2008_5digit,replace
	bys nic2008: keep if _n==1
	merge 1:m nic2008_5digit using "$output/final_data_03", keep(2 3) 
	egen dereserv_yr = group(_merge year)
	drop _merge
	gen dereserv	= (maxyear>=year)

capture drop temp*
merge  year nic2008_4digit using   "$source/tariff_master", uniqusing sort

foreach var in output_tariff input_tariff { 
	gen temp=`var' if year==2010
	bysort nic2008_4digit: egen temp2=max(temp)
	replace `var'=temp2 if year>2010
	drop temp*
	}
	gen nic2008_3digit=nic_3digit
	egen treated4 = mean(treated),by(nic2008_4 year)
	egen treated3 = mean(treated),by(nic2008_3digit year)
	

*** Generate industry-level dispersion at 5 and 4-digit levels
	gen e_mpk=exp(mpk_YK) 
	gen e_mpl=exp(mpl_YL) 

forval x=3/5 { 
	capture drop temp*
	gen temp=0
	replace temp=1 if e_mpk!=.
	bysort nic2008_`x'digit year: egen num_firms`x'=total(temp)
	bysort nic2008_`x'digit year: egen sd`x'=sd(e_mpk)
	gen var_`x'=sd`x'*sd`x'
	gen log_var_`x'=log(var_`x')
	bysort nic2008_5digit year: egen temp2=mean(treated) if e_mpk!=.
	bysort nic2008_5digit year: egen share_treated`x'=mean(temp2)
	egen ind_tag`x'=tag( nic2008_`x'digit year)
	drop sd`x'
	drop temp*
	
	capture drop temp*
	gen temp=0
	replace temp=1 if e_mpl!=.
	bysort nic2008_`x'digit year: egen num_firms`x'_mpl=total(temp)
	bysort nic2008_`x'digit year: egen sd`x'=sd(e_mpl)
	gen var_`x'_mpl=sd`x'*sd`x'
	gen log_var_`x'_mlp=log(var_`x'_mpl)
	bysort nic2008_5digit year: egen temp2=mean(treated) if e_mpl!=.
	bysort nic2008_5digit year: egen share_treated`x'_mpl=mean(temp2)
	drop sd`x'
	drop temp*
}
*** Constant variables needed to produce nice output
	gen a = 1 
	gen b = 2 
	gen c = 3 
	gen d = 4 
	
*** Additional fixed effects		
	egen dig2_year=group(nic_2digit year)	
	
*** Labels	
	label var share_treated5 "Reform"
	label var share_treated4 "Share of (4-digit) Industry Treated"
	label var share_treated3 "Share of (3-digit) Industry Treated"

save "$output/prowess_industry",replace


*** Deal with extreme outliers at industry-year level
use "$output/prowess_industry",replace

	egen uniq_ind=group( nic2008_4digit   year)
	sum uniq_ind, d
	local max=r(max)

	foreach var in sa_gross_fixed_assets_defl wage_level e_mpk e_mpl tfpr { 
		forval x=1/`max' {
			qui: _pctile `var' if uniq_ind==`x', p(5 95)
			replace `var' = r(r1) if `var'<r(r1) & uniq_ind==`x' 
			replace `var' = r(r2) if `var'>r(r2) & uniq_ind==`x' & 	`var'!=.
			}
		}
	
*number firm count for mpl and mpk
	drop num_firms* 

	foreach out in mpk mpl { 
		bysort nic2008_4digit year: egen nfirms_`out'=total(e_`out'!=.)
		}

	bysort nic2008_4digit year: egen nfirms_tfpr=total(tfpr!=.)
	
	* total capital + wages
	forval x=3/4{
		egen K`x' 		= sum(sa_gross_fixed_assets_defl),by(nic2008_`x'digit year)
		gen lK`x' 		= log(K`x')
		
		egen L`x'=sum(wage_level),by(nic2008_`x'digit year)
		gen l_L`x'=log(L`x')
	}
	
	*get industry weights
	forval x =3/4{
		egen totK`x'		= sum(sa_gross_fixed_assets_defl*(year==2000)),by(nic2008_`x')
		egen totL`x'		= sum(wage_level*(year==2000)),by(nic2008_`x')
	}
	
	forval x =3/4{
		capture drop var_* 
		capture drop sd*
		egen sd`x'			= sd(e_mpk),by(nic2008_`x' year)
		gen var_`x'			= sd`x'*sd`x'
		gen log_var_`x'_mpk	= log(var_`x')
		
		capture drop var_* 
		capture drop sd*
		egen sd`x'			= sd(e_mpl),by(nic2008_`x' year)
		gen var_`x'_mpl		= sd`x'*sd`x'
		gen log_var_`x'_mpl	= log(var_`x')
		
		capture drop var_* 
		capture drop sd*
		egen sd`x'=sd(tfpr),by(nic2008_`x' year)
		gen var_`x'_log_tfpr=sd`x'*sd`x'
		
		
		bysort nic2008_`x' year: egen dereserv`x'=mean(dereserv) 
		bysort nic2008_`x' year: egen input_tariff`x'=mean(input_tariff)
		bysort nic2008_`x' year: egen output_tariff`x'=mean(output_tariff)
		}
		
	*fill in missing tariff info
	foreach var in input_tariff output_tariff { 
		forval x=3/4 { 
			gen temp=`var'`x' if year==2000
			bysort nic2008_`x': egen temp2=mean(temp)
			replace `var'`x'=temp2 if year<2000
			drop temp*
			}
		}
	
	gen nbfirm 		= nfirms_mpk  
	gen lnbfirm 	= log(nfirms_mpk)
	gen num_firms	= nfirms_mpk
	gen lnum_firms	= log(num_firms)
	
	replace input_tariff4=input_tariff3 if input_tariff4==.
	replace output_tariff4=output_tariff3 if output_tariff4==.

	
	*we should have an industry-level treatment variable that is consistent over time and only changes based on when firms are treated, not based on changing size of sub-industries
	*use full sample to get industry level treatment 
	bysort nic2008_4: egen treat2001= mean(fdi_year_of_reform==(2001)) 
	bysort nic2008_4: egen treat2006= mean((fdi_year_of_reform==(2006)|fdi_year_of_reform==(2001)))
	
	drop treated4
	replace treated=0 if fdi_year_of_reform==1991
	bysort nic2008_4 year: egen treated4=mean(treated)
	
	gen alt_treated=0 if year<=2001
	replace alt_treated=treat2001 if year>2001 & year<=2006
	replace alt_treated=treat2006 if year>2006 
	
*** Label
	label var alt_treated "Share of (4-digit) Industry Treated"	
	
	save "$output/prowess_industry02",replace

}
*
**************************************************************
**********	REGRESSIONS PROWESS LEVEL	**********************
**************************************************************
{
*set up table output globals
	global listfeIND ///
		estfe . est* , labels(nic2008_4digit "\\[-1.8ex]\hline\textit{Fixed Effects} \\ \hspace{1.5em}Industry (4-digit) " ///
		dig2_year 			"\hspace{1.5em}Industry (2-digit)$\times$ \hspace{-0.2em}Year" ///			
		nic2008_4digit 		"\hspace{1.5em}Industry (4-digit)" ///	
		nic2008_3digit 		"\hspace{1.5em}Industry (3-digit)" ///			
		year				"\hspace{1.5em}Firm $\times$ \hspace{-0.2em}year" ///
		a 					"\addl\textit{Controls} \\ \hspace{1.5em}Output Tariff" ///
		b 					"\hspace{1.5em}Input Tariff" ///	
		c 					"\hspace{1.5em}Dereservation" ///				
		num_firms 			"\addl\textit{Controls} \\ \hspace{1.5em}Nb firms")		
		return list

		
		
*** Estimate regressions	
	eststo clear 
	use "$output/prowess_industry02",replace
	* Specify list of controls
	global policy 	"output_tariff4 input_tariff4 dereserv4"
	*capital
	eststo: reghdfe lK4 alt_treated 	if ind_tag4==1 [aw=totK4],a(nic2008_4 dig2_year) cl(nic2008_4 )
		$trueobs 
	eststo: reghdfe log_var_4_mpk alt_treated if ind_tag4==1 & nfirms_mpk >5  [aw=totK4], absorb(nic2008_4digit dig2_year ) cluster(nic2008_4digit )
		$trueobs 	
	eststo: reghdfe log_var_4_mpk alt_treated  if ind_tag4==1 & nfirms_mpk >5 [aw=totK4], absorb( num_firms  nic2008_4digit dig2_year ) cluster(nic2008_4digit)	
		$trueobs 	
	*eststo: reghdfe log_var_4_mpk alt_treated  $policy if ind_tag4==1 & nfirms_mpk >5 [aw=totK4], absorb( a b c   num_firms nic2008_4digit dig2_year ) cluster(nic2008_4digit)
	*	$trueobs 
		
	$listfeIND
	esttab  using "$result/variance_prowess_Konly.tex", ///
	$gorgeous3 mgroups(\vspace{-.3cm}\multicolumn{@span}{c}{}) nonumber keep(_cons alt_treated) ///
	indicate( `r(indicate_fe)', labels($\checkmark$ --- )) 
	
			
	*labor
	replace num_firms=nfirms_mpl
	replace lnum_firms=log(num_firms)
	eststo: reghdfe l_L4 alt_treated 	if ind_tag4==1 [aw=totK4] ,a(nic2008_4 dig2_year) cl(nic2008_4)
		$trueobs 	
		
	eststo: reghdfe log_var_4_mpl alt_treated [aw=totK4]	if ind_tag4==1 & nfirms_mpl >5 ,a(nic2008_4 dig2_year) cl(nic2008_4)
		$trueobs
		
	eststo: reghdfe log_var_4_mpl alt_treated lnum_firms if ind_tag4==1 & nfirms_mpl>5 [aw=totK4], absorb( nic2008_4digit dig2_year ) cluster(nic2008_4digit)	
		$trueobs 	
	eststo: reghdfe log_var_4_mpl alt_treated lnum_firms $policy if ind_tag4==1 & nfirms_mpl>5 [aw=totK4], absorb( a b c  nic2008_4digit dig2_year ) cluster(nic2008_4digit)
		$trueobs 

	$listfeIND
	esttab  using "$result/variance_prowess_new.tex", ///
	$gorgeous3 mgroups(\vspace{-.3cm}\multicolumn{@span}{c}{}) nonumber keep( _cons alt_treated) ///
	indicate( `r(indicate_fe)', labels($\checkmark$ --- )) 
	
	*tfpr--prowess
	eststo clear
	
	replace num_firms=nfirms_tfpr
	replace lnum_firms=log(num_firms)
		
	eststo: reghdfe var_4_log_tfpr alt_treated [aw=totK4]	if ind_tag4==1 & num_firms >5 ,a(nic2008_4 dig2_year) cl(nic2008_4)
		$trueobs
		
	eststo: reghdfe var_4_log_tfpr alt_treated lnum_firms if ind_tag4==1 & num_firms>5 [aw=totK4], absorb(a nic2008_4digit dig2_year ) cluster(nic2008_4digit)	
		$trueobs 	

	estfe . est* , labels( ///
		nic2008_4digit 	"\\[-1.8ex]\hline\textit{Fixed Effects} \\ \hspace{1.5em}Industry (4-digit) " ///
		dig2_year 	"\hspace{1.5em}Industry (2-digit)$\times$ \hspace{-0.2em}Year" ///	
		a 					"\addl\textit{Controls} \\ \hspace{1.5em}Nb firms")			
	return list	
	esttab  using "$result/variance_prowess_tfpr.tex", ///
	$gorgeous3 mgroups(\vspace{-.3cm}\multicolumn{@span}{c}{}) nonumber keep( _cons alt_treated) ///
	indicate( `r(indicate_fe)', labels($\checkmark$ --- )) 
}
*	
	
**********************************************************
**********	REGRESSIONS ASI LEVEL	**********************
**********************************************************
{	
*** Get alphas estimated in Prowess to use with ASI to get TFPR
	use "$output/prowess_industry",replace

	rename nic08_4digit nic08_perm
	destring nic08_perm, replace

	keep nic08_perm L_coeff K_coeff M_coeff
	foreach var in L_coeff K_coeff M_coeff { 
		bysort nic08_perm: egen temp=mean(`var')
		replace `var'=temp
		drop temp
		}
	duplicates drop
	save "$output/alphas", replace

use "$output/asi9815_final", clear

*merge in alphas from prowess
merge m:1 nic08_perm using  "$output/alphas",nogen keep(1 3) 

foreach var in L_coeff K_coeff M_coeff { 
	bysort nic04_perm: egen temp=mean(`var')
	replace `var'=temp
	drop temp
	}

*** MPL
	gen mpl	= sale/emp
*** Three versions of TFPR 
	* LP coefficients
	gen tfpr1 = log(sale)-L_coeff*log(emp)-K_coeff*log(K_n)
	* Cost share 
	gen nic02_perm	= floor(nic04_perm/100)	
	gen Mw_share	= (wages*mult)/(sale*mult)
	replace Mw_share = 1 if Mw_share>1
	egen w_share	= mean(Mw_share),by(nic02_perm)
	gen tfpr2 		= log(sale)-w_share*log(emp)-(1-w_share)*log(K_n)
	* weighted sums of MPK and MPL as in HK (09)
	gen mpl_wage 	= sale  / wages
	replace mpl_wage = . if mpl_wage <1 // total sales should be at least as big as total wage
	gen tfpr3		= w_share*log(mpl_wage) + (1-w_share)*log(mpk)
	
	foreach var in a b c{
		gen `var'=1
	}
	bysort nic04_perm year: gen nbfirm=_N
	
*** Make weights symmetric to Prowess (industry total capital in 2000)
	cap drop w
	bysort nic04_perm: egen w=total(K_n*mult*(year==2000))
	bysort nic04_perm: egen s=total(sale*mult*(year==2000))
	
	bysort nic04_perm: egen treat2001= mean(fdi_04==(2001)) 
	bysort nic04_perm: egen treat2006= mean((fdi_04==(2006)|fdi_04==(2001)))
	
	gen alt_treated=0 if year<=2001
	replace alt_treated=treat2001 if year>2001 & year<=2006
	replace alt_treated=treat2006 if year>2006 
	
	egen uniq_ind=group(nic04_perm year)
	sum uniq_ind, d
	local max=r(max)

	foreach var in K_n wages mpk mpl mpl_wage tfpr1 tfpr1 tfpr3{ 
	forval x=1/`max' {
		qui: _pctile `var' if uniq_ind==`x', p(5 95)
		replace `var' = r(r1) if `var'<r(r1) & uniq_ind==`x'
		replace `var' = r(r2) if `var'>r(r2) & uniq_ind==`x' & `var'!=.
		}
	}		
	foreach out in mpk mpl mpl_wage tfpr1 tfpr2 tfpr3{ 
		bysort nic04_perm year: egen nfirms_`out'=total(`out'!=.)
		}
	gen lmpk 		= log(mpk)	
	gen lmpl_wage	= log(mpl_wage)
	gen lmpl		= log(mpl)
save "$output/asi9815_final_winsor", replace
	
	
*** Collapse and run regression
use "$output/asi9815_final_winsor", replace
	
	collapse (sum) wages emp K_n (mean)  w s  shockP alt_treated nfirms_* nic04_2yr output_tariff input_tariff dereserv ///
	(sd) lmpk* mpl_wage lmpl lmpl_wage mpk* tfpr* [w=mult] , by(nic04_perm year)

	* Constant for outputted tables
	gen a=1
	gen b=1
	gen c=1
	
	* log outcomes
	gen l_K_ind			= log(K_n)
	gen l_var_mpk		= log(mpk*mpk)
	gen l_var_mpl		= log(mpl*mpl)
	gen l_emp_ind		= log(emp)
	gen l_wage_ind		= log(wages)
	gen lnum_firms		= log(nfirms_mpk)
	gen var_lmpk		= lmpk*lmpk
	gen var_lmpl_wage	= lmpl_wage*lmpl_wage
	gen var_lmpl		= lmpl_wage*lmpl	
	gen var_lmpk2		= lmpk2*lmpk2
	gen var_tfpr2		= tfpr2*tfpr2
	gen var_tfpr3		= tfpr2*tfpr3
	
	* label 
	label var alt_treated "Share of (4-digit) Industry Treated"
	
save "$output/asi9815_final_winsor02", replace

*** Run regressions	
	eststo clear 
	use "$output/asi9815_final_winsor02", clear
	gen num_firms = 1

	global policy_con output_tariff  input_tariff dereserv 	
		
	// Capital
	eststo: reghdfe l_K_ind  alt_treated  [aw=w] ,a(  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	
	eststo: reghdfe l_var_mpk  alt_treated [aw=w] if nfirms_mpk>5 ,a( nic04_perm nic04_2yr) cl(nic04_perm )
	$trueobs

	eststo: reghdfe l_var_mpk alt_treated lnum_firms [aw=w] if nfirms_mpk>5 , a(num_firms  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	
	estfe . est* , labels( ///
		nic04_perm 	"\\[-1.8ex]\hline\addl\textit{Fixed Effects} \\ \hspace{1.5em}Industry (4-digit) " ///
		nic04_2yr 	"\hspace{1.5em}Industry (2-digit)$\times$ \hspace{-0.2em}Year" ///	
		a 					"\addl\textit{Controls} \\ \hspace{1.5em}Output Tariff" ///
		b 					"\hspace{1.5em}Input Tariff" ///	
		c 					"\hspace{1.5em}Dereservation" ///				
		num_firms 			"\addl\textit{Controls} \\ \hspace{1.5em}Nb firms")			
	return list

	esttab  using "$result/asi_result_industryDID_Konly.tex", ///
	mgroups(\vspace{-.3cm}\multicolumn{@span}{c}{}) nonumber ///
	$gorgeous3 noobs keep(_cons alt_treated) ///
	indicate( `r(indicate_fe)', labels($\checkmark$ --- ))
	
	// Labor: emp
	replace lnum_firms=log(nfirms_mpl)
	
	reghdfe l_emp_ind  alt_treated  [aw=w] if nfirms_mpl>5 ,a(nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	
	eststo: reghdfe l_wage_ind  alt_treated  [aw=w] if nfirms_mpl>5 ,a(  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	
	eststo: reghdfe l_var_mpl  alt_treated [aw=w] if nfirms_mpl>5  ,a( nic04_perm nic04_2yr) cl(nic04_perm )
	$trueobs

	eststo: reghdfe l_var_mpl alt_treated lnum_firms [aw=w] if nfirms_mpl>5 , a(  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	
	eststo: reghdfe l_var_mpl alt_treated $policy_con  lnum_firms [aw=w] if nfirms_mpl>5 ,a(a b c  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs

	estfe . est* , labels( ///
		nic04_perm 	"\\[-1.8ex]\hline\addl\textit{Fixed Effects} \\ \hspace{1.5em}Industry (4-digit) " ///
		nic04_2yr 	"\hspace{1.5em}Industry (2-digit)$\times$ \hspace{-0.2em}Year" ///	
		a 					"\addl\textit{Controls} \\ \hspace{1.5em}Output Tariff" ///
		b 					"\hspace{1.5em}Input Tariff" ///	
		c 					"\hspace{1.5em}Dereservation" ///				
		num_firms 				"\hspace{1.5em}Nb firms")			
	return list
	
	esttab  using "$result/asi_result_industryDID.tex", ///
	mgroups(\vspace{-.3cm}\multicolumn{@span}{c}{}) nonumber ///
	$gorgeous3 noobs keep(_cons alt_treated) ///
	indicate( `r(indicate_fe)', labels($\checkmark$ --- ))
	
*** Labor and wages outcomes in ASI 
	use "$output/asi9815_final_winsor02", clear
	eststo clear 
	replace lnum_firms=log(nfirms_mpl)

	eststo: reghdfe l_emp_ind  alt_treated  [aw=w] if nfirms_mpl>5 ,a(nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs

	eststo: reghdfe l_emp_ind  alt_treated  lnum_firms [aw=w] if nfirms_mpl>5 ,a(a nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	
	eststo: reghdfe l_wage_ind  alt_treated  [aw=w] if nfirms_mpl>5 ,a(  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	eststo: reghdfe l_wage_ind  alt_treated  lnum_firms [aw=w] if nfirms_mpl>5 ,a(a  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs

	estfe . est* , labels( ///
		nic04_perm 	"\\[-1.8ex]\hline\addl\textit{Fixed Effects} \\ \hspace{1.5em}Industry (4-digit) " ///
		nic04_2yr 	"\hspace{1.5em}Industry (2-digit)$\times$ \hspace{-0.2em}Year" ///	
		a 					"\addl\textit{Controls} \\ \hspace{1.5em}Nb firms")			
	return list
	
	esttab  using "$result/asi_emp_wages.tex", ///
	mgroups(\vspace{-.3cm}\multicolumn{@span}{c}{}) nonumber ///
	$gorgeous3 noobs keep(_cons alt_treated) ///
	indicate( `r(indicate_fe)', labels($\checkmark$ --- ))
	
	
*** TEST: var log(mpk)	- var log(mpl)
	eststo clear 
	// Capital
	eststo: reghdfe l_K_ind  alt_treated  [aw=w] ,a(  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	eststo: reghdfe var_lmpk  alt_treated [aw=w] if nfirms_mpk>5 ,a( nic04_perm nic04_2yr) cl(nic04_perm )
	$trueobs
	eststo: reghdfe var_lmpk alt_treated lnum_firms [aw=w] if nfirms_mpk>5 , a(  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	eststo: reghdfe var_lmpk alt_treated $policy_con lnum_firms [aw=w] if nfirms_mpk>5  ,a(a b c  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs 
	reghdfe l_emp_ind  alt_treated  [aw=w] if nfirms_mpl>5 ,a(nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	
	* L
	eststo: reghdfe l_wage_ind  alt_treated  [aw=w] if nfirms_mpl>5 ,a(  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	eststo: reghdfe var_lmpl_wage  alt_treated [aw=w] if nfirms_mpl>5  ,a( nic04_perm nic04_2yr) cl(nic04_perm )
	$trueobs
	eststo: reghdfe var_lmpl_wage alt_treated lnum_firms [aw=w] if nfirms_mpl>5 , a(  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	eststo: reghdfe var_lmpl_wage alt_treated $policy_con  lnum_firms [aw=w] if nfirms_mpl>5 ,a(a b c  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	
	estfe . est* , labels( ///
		nic04_perm 	"\\[-1.8ex]\hline\textit{Fixed Effects} \\ \hspace{1.5em}Industry (4-digit) " ///
		nic04_2yr 	"\hspace{1.5em}Industry (2-digit)$\times$ \hspace{-0.2em}Year" ///	
		a 					"\addl\textit{Controls} \\ \hspace{1.5em}Output Tariff" ///
		b 					"\hspace{1.5em}Input Tariff" ///	
		c 					"\hspace{1.5em}Dereservation" ///				
		num_firms 				"\hspace{1.5em}Nb firms")			
	return list

	esttab  using "$result/asi_result_industryDID_K_L_varlog.tex", ///
	mgroups(\vspace{-.3cm}\multicolumn{@span}{c}{}) nonumber ///
	$gorgeous3 noobs keep(_cons alt_treated) ///
	indicate( `r(indicate_fe)', labels($\checkmark$ --- ))
	
	
	*tfpr
	eststo clear
	replace lnum_firms=log(nfirms_tfpr2)
	forval i = 2/3{
	eststo: reghdfe var_tfpr`i'  alt_treated [aw=w] if nfirms_tfpr2>5  ,a( nic04_perm nic04_2yr) cl(nic04_perm )
	$trueobs

	eststo: reghdfe var_tfpr`i' alt_treated lnum_firms [aw=w] if nfirms_tfpr2>5 , a(  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	

	eststo: reghdfe var_tfpr`i' alt_treated $policy_con  lnum_firms [aw=w] if nfirms_tfpr2>5 ,a(a b c  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs
	}

	estfe . est* , labels( ///
		nic04_perm 	"\\[-1.8ex]\hline\textit{Fixed Effects} \\ \hspace{1.5em}Industry (4-digit) " ///
		nic04_2yr 	"\hspace{1.5em}Industry (2-digit)$\times$ \hspace{-0.2em}Year" ///	
		a 					"\addl\textit{Controls} \\ \hspace{1.5em}Output Tariff" ///
		b 					"\hspace{1.5em}Input Tariff" ///	
		c 					"\hspace{1.5em}Dereservation" ///				
		num_firms 				"\hspace{1.5em}Nb firms")			
	return list
	esttab  using "$result/asi_var_logtfpr.tex", ///
	mgroups(\vspace{-.3cm}\multicolumn{@span}{c}{}) nonumber ///
	$gorgeous3 noobs keep(_cons alt_treated) ///
	indicate( `r(indicate_fe)', labels($\checkmark$ --- ))
}
*	

**********************************************************************
**********	REGRESSIONS MRPL PROWESS AND ASI 	**********************
**********************************************************************
{
	eststo clear 

	* Specify list of controls
	global policy 	"output_tariff4 input_tariff4 dereserv4"
	
*** Prowess	
	eststo clear
	use "$output/prowess_industry02",replace

	replace num_firms=nfirms_mpl
	replace lnum_firms=log(num_firms)
	* make sure output of fixed effects is the same across datasets
	gen nic04_perm 	= nic2008_4
	gen nic04_2yr	= dig2_year
	
	eststo: reghdfe log_var_4_mpl alt_treated [aw=totK4]	if ind_tag4==1 & nfirms_mpl >5 ,a(nic04_perm nic04_2yr) cl(nic2008_4)
		$trueobs	
	eststo: reghdfe log_var_4_mpl alt_treated lnum_firms if ind_tag4==1 & nfirms_mpl>5 [aw=totK4], absorb(a nic04_perm nic04_2yr) cluster(nic2008_4digit)	
		$trueobs 	

*** ASI		
	use "$output/asi9815_final_winsor02", clear
	gen num_firms=nfirms_mpl
	replace lnum_firms=log(num_firms)
	
	
	eststo: reghdfe l_var_mpl  alt_treated [aw=w] if nfirms_mpl>5  ,a( nic04_perm nic04_2yr) cl(nic04_perm )
	$trueobs

	eststo: reghdfe l_var_mpl alt_treated lnum_firms [aw=w] if nfirms_mpl>5 , a(a  nic04_perm nic04_2yr ) cl(nic04_perm )
	$trueobs

	estfe . est* , labels( ///
		nic04_perm 	"\\[-1.8ex]\hline\textit{Fixed Effects} \\ \hspace{1.5em}Industry (4-digit) " ///
		nic04_2yr 	"\hspace{1.5em}Industry (2-digit)$\times$ \hspace{-0.2em}Year" ///	
		a 			"\addl\textit{Controls} \\ \hspace{1.5em}Nb firms")			
	return list
	
	esttab  using "$result/log_var_mprl_asi_prowess.tex", ///
	mgroups(\vspace{-.3cm}\multicolumn{@span}{c}{}) nonumber ///
	$gorgeous3 noobs keep(_cons alt_treated) ///
	indicate( `r(indicate_fe)', labels($\checkmark$ --- ))

}
*





