

*** Total foreign equity at the nic5-year level 
	// Extract foreign equity 
	use shp_cocode company_name shp_date total_equity frgn_promoters_equity fii_equity frgn_venture_cap_equity using "$source/equity", clear  
    // to be used for merging with final data
	tostring shp_date,replace
	gen date1 = substr(shp_date,1,4)
	gen date2 = substr(shp_date,5,2)
	gen date3 = substr(shp_date,7,2)
	replace shp_date = date1+"-"+date2+"-"+date3
    gen date = date(shp_date, "YMD")
    gen year = year(date)
    rename shp_cocode sa_finance1_cocode
    // keep only equity count from last reported date
    gsort company_name year
    egen max_date = max(date), by(company_name year)
    keep if date == max_date
	
	foreach var in frgn_promoters_equity  fii_equity  frgn_venture_cap_equity {
		replace `var' = "." if `var' =="NA"
	}
	destring frgn_promoters_equity  fii_equity  frgn_venture_cap_equity  total_equity, replace
	foreach var in frgn_promoters_equity  fii_equity  frgn_venture_cap_equity {
		recode `var' . =  0
	}	
    // foreign equity shares variables
    gen share_foreign_equity 		= (frgn_promoters_equity + fii_equity + frgn_venture_cap_equity) / total_equity
    gen share_frgn_equity_promoters = frgn_promoters_equity / total_equity
	gen tot_foreign_equity 			= (frgn_promoters_equity + fii_equity + frgn_venture_cap_equity)
	
	gcollapse(mean) tot_foreign_equity,by(sa_finance1_cocode year)
	drop if tot_foreign_equity == 0 
    save "$output/firm_equity_temp", replace
	
	// Bring nic5 and compute different measures
	use sa_finance1_cocode nic2008_5digit using "$output/firms_financials", replace
	bys sa_finance1_cocode: keep if _n==1
	merge 1:m sa_finance1_cocode using "$output/firm_equity_temp", nogen keep(3)
	collapse(sum) ind_equity  = tot_foreign_equity,by(nic2008_5digit year)
	destring nic2008_5digit,replace force
	* create a proper panel and fills with zeros 
	xtset nic2008_5digit year 
	tsfill
	recode ind_equity . = 0 
	
	* Level 
	gen log_ind_equity	= log(ind_equity)
	gen ihs_equity		= asinh(ind_equity)	
	
	* Growth in FDI from 2001-2005
	egen fdi_2001 		= max(ihs_equity*(year==2001)),by(nic2008_5digit)
	egen fdi_2005 		= max(ihs_equity*(year==2005)),by(nic2008_5digit)
	gen fdi_growth		= (fdi_2005-fdi_2001)/fdi_2001 // missings due to 0's 
	gen ihs_fdi_growth	= asinh(fdi_2005)-asinh(fdi_2001)
    save "$output/firm_equity_indlevel", replace
	erase "$output/firm_equity_temp.dta"

***Part 1: MRPK Dispersion and Other Industry-Level Attributes
use "$output/final_data_03", replace
destring nic2008_5digit,replace
*** Make weights for consistent weighting with other industry-level table 
	egen totK = sum(sa_gross_fixed_assets_defl*(year==2000)),by(nic2008_5digit )
	
*** Three options: predict treatment relative to never treated, already treated, both
	gen reformed=0
	replace reformed=1 if fdi_year_of_reform==2001 | fdi_year_of_reform==2006
	
*** Bring equity 
	merge m:1 nic2008_5digit year using "$output/firm_equity_indlevel", nogen keep(1 3)
	
*** Calculate 5-digit level dispersion 
	gen e_mpk=exp(mpk_YK) 
	local x=5
		capture drop temp*
		gen temp=0
		replace temp=1 if e_mpk!=.
		bysort nic2008_`x'digit year: egen sd`x'=sd(e_mpk)
		gen var_`x'=sd`x'*sd`x'
		gen log_var_`x'=log(var_`x')
		egen ind_tag`x'=tag( nic2008_`x'digit year)
		drop sd`x'
		drop temp*
		
		bysort nic2008_`x'digit year: egen share_gov=mean(gov_owned)
		bysort nic2008_`x'digit year: gen num_firms=_N
		bysort nic2008_`x'digit year: egen mean_cap=mean(sa_gross_fixed_assets_defl)
		bysort nic2008_`x'digit year: egen share_export=mean(s_export)

*** Average variance in pre-treatment period
	gen temp=log_var_`x' if year<=2000
	bysort nic2008_`x'digit: egen avg_var=mean(temp)
	drop temp

	egen log_mean_cap=mean(log(sa_gross_fixed_assets_defl)) if year<=2000,by(nic2008_5digit)

*** Calculate hhi
	egen total_sales= sum(sa_sales_year),by(nic2008_5digit year)
	gen sale_share	= (sa_sales_year/total_sales)
	egen hhi		= sum(sale_share^2),by(nic2008_5digit year)
	replace hhi		=. if year!=2000
	egen temp		= mean(hhi),by(nic2008_5digit)
	replace hhi		= temp
	drop temp

	bysort nic2008_5digit year: egen state_sales_share=total(state*sale_share) if year==2000
	replace state_sales_share=state_sales_share/total_sales if year==2000

*** Label
	label var avg_var "Mean Variance in MRPK, 1995-2000"
	label var log_var_5 "Mean Variance in MRPK"
	label var num_firms "Num. Firms"
	label var mean_cap "Avg. Firm Capital"
	label var log_mean_cap "Log Avg. Firm Capital"
	label var hhi "Herfindahl Index"
	label var state_sales_share "State-Owned Firms Share of Total Sales"
	label var share_export "Share Export"
	label var ihs_equity "Ihs(Industry-Level FDI)"
	label var fdi_growth "FDI Growth, 2001-2005"
	label var ihs_fdi_growth "Ihs(FDI 2005)-Ihs(FDI 2001)"
	
	save "$output/predicted_sample",replace
	
*** UNWEIGHTED REGRESSIONS	
	eststo clear
	// Does average variance between 1995-2000 predict being reformed? [Using only 2000 gives similar results]
	*relative to only never-reformed
	eststo: reg reformed log_var_5 if ind_tag5==1 & (fdi_year_of_reform!=1991) & year==2000, r

	// Number medium + large firms in industry
	eststo: reg reformed num_firms if ind_tag5==1 & (fdi_year_of_reform!=1991) & year==2000, r

	// Avg. firm size in industry
	eststo: reg reformed log_mean_cap if ind_tag5==1 & (fdi_year_of_reform!=1991) & year==2000, r
	
	// SOE share
	eststo: reg reformed state_sales_share if ind_tag5==1 & (fdi_year_of_reform!=1991) & year==2000, r

	// hhi
	eststo: reg reformed hhi if ind_tag5==1 & (fdi_year_of_reform!=1991) & year==2000, r
	
	// Levels of FDI at industry-level
	* 2001 level, might be endogenous to reform
	eststo: reg reformed ihs_equity if ind_tag5==1  & year==2001 & fdi_year_of_reform!=1991, r

	* Restrict to looking at 2006 reform
	eststo: reg reformed ihs_equity if ind_tag5==1  & year==2005 & fdi_year_of_reform!=1991 & fdi_year_of_reform!=2001, r
	
	// Growth of FDI (by definition we can only look at 2006 reform)
	eststo: reg reformed fdi_growth if ind_tag5==1  & year==2005 & fdi_year_of_reform!=1991 & fdi_year_of_reform!=2001, r

	eststo: reg reformed ihs_fdi_growth if ind_tag5==1  & year==2005 & fdi_year_of_reform!=1991 & fdi_year_of_reform!=2001, r
	
	esttab  using "$result/predict_reform.tex",  ///
		cells(b(fmt(%8.3f) star) se(fmt(%8.3f) par))  ///
		starlevels(  * .100 ** .050 *** .01) ///
		varwidth(50) nolines  posthead(\midrule) label replace	///
		fragment mlabels(none) collabels(none) drop(_cons) booktab   ///		
		stats(N, fmt(%8.0fc) label("\\[-1.8ex]\hline\\[-1.8ex]\vspace{0.1em}Observations")) nonotes
	

*** WEIGHTED REGRESSIONS	
	eststo clear
	// Does average variance between 1995-2000 predict being reformed? [Using only 2000 gives similar results]
	*relative to only never-reformed
	eststo: reg reformed log_var_5 if ind_tag5==1 & (fdi_year_of_reform!=1991) & year==2000 [aw=totK], r

	// Number medium + large firms in industry
	eststo: reg reformed num_firms if ind_tag5==1 & (fdi_year_of_reform!=1991) & year==2000 [aw=totK], r

	// Avg. firm size in industry
	eststo: reg reformed log_mean_cap if ind_tag5==1 & (fdi_year_of_reform!=1991) & year==2000 [aw=totK], r
	
	// Share export
	eststo: reg reformed share_export [aw=totK] if ind_tag5==1  & year==2005 & fdi_year_of_reform!=1991 & fdi_year_of_reform!=2001, r

	// SOE share
	eststo: reg reformed state_sales_share if ind_tag5==1 & (fdi_year_of_reform!=1991) & year==2000 [aw=totK], r

	// hhi
	eststo: reg reformed hhi if ind_tag5==1 & (fdi_year_of_reform!=1991) & year==2000 [aw=totK], r
	
	// Levels of FDI at industry-level
	* 2001 level, might be endogenous to reform
	eststo: reg reformed ihs_equity if ind_tag5==1  & year==2001 & fdi_year_of_reform!=1991 [aw=totK], r

	
	// Growth of FDI (by definition we can only look at 2006 reform)
	eststo: reg reformed fdi_growth if ind_tag5==1  & year==2005 & fdi_year_of_reform!=1991 & fdi_year_of_reform!=2001 [aw=totK], r

	eststo: reg reformed ihs_fdi_growth if ind_tag5==1  & year==2005 & fdi_year_of_reform!=1991 & fdi_year_of_reform!=2001 [aw=totK], r
	
	esttab  using "$result/predict_reform_weighted.tex",  ///
		cells(b(fmt(%8.3f) star) se(fmt(%8.3f) par))  ///
		starlevels(  * .100 ** .050 *** .01) ///
		varwidth(50) nolines  posthead(\midrule) label replace	///
		fragment mlabels(none) collabels(none) drop(_cons) booktab   ///		
		stats(N, fmt(%8.0fc) label("\\[-1.8ex]\hline\\[-1.8ex]\vspace{0.1em}Observations")) nonotes

		
*** WEIGHTED REGRESSIONS: WORKING SAMPLE 
	use "$output/predicted_sample",replace
	gen lf = log(num_firms)
	label var lf "Log(Num. Firms)"

	eststo clear
	drop if log_var_5==.
	keep if ind_tag5==1
	recode ihs_equity . = 0 
	replace reformed = 0 if fdi_year_of_reform==1991
	
	* only use pre-reform values 
	foreach var in log_var_5 fdi_year_of_reform lf log_mean_cap share_export state_sales_share hhi{
		replace `var' = . if year>=2001
	}
	
	* slight adjustment for fdi variables 
	foreach var in fdi_growth ihs_fdi_growth{
		replace `var' = . if year>=2006
	}
	replace ihs_equity = . if  year>=2002
	
	
	gcollapse(mean) reformed log_var_5 fdi_year_of_reform totK lf log_mean_cap share_export state_sales_share hhi ihs_equity fdi_growth ihs_fdi_growth,by(nic2008_5digit)
	drop if log_var_5==.
	recode state_sales_share . = 0
	eststo clear 
	label var log_var_5 "Log (Variance in MRPK)"
	label var lf "Log (Num. Firms)"
	label var log_mean_cap "Log (Avg. Firm Capital)"
	label var hhi "Herfindahl Index"
	label var state_sales_share "State-Owned Firms Share of Total Sales"
	label var share_export "Share Export"
	label var ihs_equity "Ihs(Industry-Level FDI)"
	label var fdi_growth "FDI Growth, 2001-2005"
	label var ihs_fdi_growth "Ihs(FDI 2005)-Ihs(FDI 2001)"
	
	foreach var in log_var_5 lf log_mean_cap share_export state_sales_share hhi ihs_equity{ 
		eststo: reg reformed `var' [aw=totK], r
	}
	* drop deregulated sector in 2001 to estimate the role of changes in foreign equity on 2006 reform
	drop if fdi_year_of_reform==2001
	foreach var in fdi_growth ihs_fdi_growth{ 
		eststo: reg reformed `var' [aw=totK], r
	}
	esttab  using "$result/predict_reform_weighted2.tex",  ///
		cells(b(fmt(%8.3f) star) se(fmt(%8.3f) par))  ///
		starlevels(  * .100 ** .050 *** .01) ///
		varwidth(50) nolines  posthead(\midrule) label replace	///
		fragment mlabels(none) collabels(none) drop(_cons) booktab   ///		
		stats(N, fmt(%8.0fc) label("\\[-1.8ex]\hline\\[-1.8ex]\vspace{0.1em}Observations")) nonotes

		
