


***********************************************************
**********		ESTIMATE LP		***************************
***********************************************************

*** call the modified version of LP 
	do "$do/levpet/levpet_dw.do"
	do "$do/levpet/levept_p_dw.do"
	do "$do/levpet/lp_bs_ss_dw.do"
	do "$do/levpet/lp_gmm_dw.do"
	do "$do/levpet/lp_gmm_grid_dw.do"
	do "$do/levpet/lp_srch_dw.do"
	do "$do/levpet/nllp_bs_gmm_dw.do"
	
*** extract the right variables firm financial 
global tfpvar "nic2_adj sale wage* M* K* L* id year E"
	use $tfpvar using "$output/final_data_notfpq", clear
	rename wage L 
	foreach var in L K M {
	gen `var'_coeff = .
	}
	
	local bootstrap_reps = 2  
	
	local nic_class "nic2_adj"
    levelsof `nic_class', local(nic_class_list)
			
	foreach nc of local nic_class_list {	
	preserve
	local bootstrap_reps = 2  
	keep if `nic_class'==`nc' 
    display in red "NIC 2-Digit: `nc' from `nic_class'"
	local free_var "L"
	local proxy_var_mat "M"
	local proxy_var_pow "E"
	local cap_stock "K"
	
	// Classic LP 
    quietly : levpet_dw sale , ///
    free(`free_var') proxy(`proxy_var_mat') capital(`cap_stock') revenue reps(`bootstrap_reps') i(id) t(year) 

   * save coefficients to var
   quiet cap replace L_coeff = _b[`free_var'] if `nic_class'==`nc'
   quiet cap replace K_coeff = _b[`cap_stock'] if `nic_class'==`nc'
   quiet cap replace M_coeff = _b[`proxy_var_mat'] if `nic_class'==`nc'
  	keep *coeff* `nic_class'
    * save estimates of parameters to table **
    save "$output/tfp_coeff_nic2_`nc'", replace
	restore  
}	
	
*** NOW ASSEMBLE EVERYTHING
	use nic2_adj using "$output/final_data_notfpq", replace 

    levelsof nic2_adj, local(nic_class_list_coeff)

	clear
	save "$output/lp_coeff", replace emptyok // blank table that will eventually become a panel with all the variables
	foreach nc of local nic_class_list_coeff {
	display in red "`nc'"
	append using "$output/tfp_coeff_nic2_`nc'"
	erase "$output/tfp_coeff_nic2_`nc'.dta"
	}
	bys nic2_adj: keep if _n==1
	save "$output/lp_coeff", replace

	
*** Estimate TFPR and TFPQ
	* Compute unit price 
	use "$output/product_clean",replace
	* Average price of the product portfolio
	egen tot = sum(sales_value),by(id year)
	gen w	= sales_value / tot
	collapse(mean) price [aw=w],by(id year)
	trim_var price 1
	replace price = price_t1
	save "$output/firm_unit_price", replace 

	use $tfpvar using "$output/final_data_notfpq", clear

	* LP 
	merge m:1 nic2_adj using "$output/lp_coeff",nogen
	
	* bring prices 
	merge m:1 id year using "$output/firm_unit_price",nogen keep(1 3)

	gen lprice	= log(price)
	
	* winsor 
	foreach var in sale wage M K lprice{
	trim_var `var' 	1
	}
	
	* TFPR
	gen tfpr	= sale - (L_coeff*wage) - (M_coeff*M) - (K_coeff*K)

*	gen tfpr	= sale - (L_coeff*L_raw) - (M_coeff*M_raw) - (K_coeff*K_raw)
	
	*winsor tfpr 1 
	trim_var tfpr 1
	
	* TFPQ
	gen tfpq	= tfpr - lprice
	*replace tfpq	= log(tfpq) 
	gen tfpq_t1	= tfpr_t1 - lprice_t1
	
	keep *tfpq* tfpr* id year L_coeff M_coeff K_coeff
	*keep *tfpq* tfpr* id year
		
	save "$output/tfpr_tfpq",replace
	
	
